(function(wp) {
    var el = wp.element.createElement;
    var InspectorControls = wp.blockEditor.InspectorControls;
    var RichText = wp.blockEditor.RichText;
    var Fragment = wp.element.Fragment;
    var InnerBlocks = wp.blockEditor.InnerBlocks;
    var MediaUpload = wp.blockEditor.MediaUpload;
    var TextControl = wp.components.TextControl;
    var RangeControl = wp.components.RangeControl;
    var SelectControl = wp.components.SelectControl;
    var ButtonGroup = wp.components.ButtonGroup;
    var Button = wp.components.Button;
    var ColorPalette = wp.components.ColorPalette;
    var __ = wp.i18n.__;
	var plugin_url = cwp_options.plugin_url;

    wp.blocks.registerBlockType('cwp/container-fancy-animated', {
        title: __('Container Fancy Animated', 'cosmic-blocks'),
		keywords: [
			'container-fancy-animated',
			__('wrapper', 'cosmic-blocks'),
			__('content', 'cosmic-blocks')
		],
        icon: {
			background: "#16A3FF",
			foreground: "#FFFFFF",
			src: "category"
		},
        category: 'cwp-blocks',
        attributes: {
			blockID: {
				type: 'string',
				default: ''
			},
			blockAutoID: {
				type: 'string',
				default: 'empty'
			},
            columns: {
                type: "number",
                default: 1
            },
            container: {
                type: "string",
                default: 'cwp-full-width-wide-container'
            },
			thumbnailSize: {
				type: "string",
                default: ''
			},
			imagePosition: {
				type: "string",
                default: 'cwp-image-left'
			},
            backgroundType: {
				type: "string",
				default: 'color'
            },
            backgroundTextColor: {
                type: "string",
                default: ''
            },
            solidColor: {
                type: "string",
                default: ''
            },
            gradient: {
                type: "string"
            },
            backgroundMediaID: {
                type: "number"
            },
            backgroundMediaURL: {
                type: "string"
            },
            animationStyle: {
                type: "string"
            },
            animationDelay: {
                type: "number",
                default: 10
            },
            threshold: {
                type: "number",
                default: 40
            },
            paddingBeforeIntro: {
                type: 'number',
                default: 50
            },
            paddingAfterIntro: {
                type: 'number',
                default: 50
            },
            paddingAfterItems: {
                type: 'number',
                default: 50
            },
			introsection: {
                type: 'string',
                default: 'empty'
            },
            introtitle: {
                type: "string",
                default: ''
            },
            introsubtitle: {
                type: "string",
                default: ''
            },
            introduction: {
                type: "string",
                default: ''
            },
            color: {
                type: "string",
                default: ""
            },
			imageContainerOffset: {
                type: 'string',
                default: 'no'
            },
			imageContainerOffsetPx: {
                type: 'number',
                default: 0
            },
			imageContainerWidth: {
                type: 'number',
                default: -1
            },
			animatedContainerWidth: {
                type: 'string',
                default: 'auto'
            },
			animatedContainerWidthPx: {
                type: 'number',
                default: -1
            },
			mediaID: {
                type: "number"
            },
            mediaURL: {
                type: "string"
            },
			fancyBackgroundType: {
                type: "string",
                default: 'color'
            },
            fancyBackgroundSolidColor: {
                type: "string",
                default: ''
            },
            fancyBackgroundGradient: {
                type: "string"
            },
            fancyBackgroundMediaID: {
                type: "number"
            },
            fancyBackgroundMediaURL: {
                type: "string"
            }
        },
        getEditWrapperProps({
            container
        }) {
            if ('cwp-full-width-wide-container' === container || 'cwp-full-width-small-container' === container || 'cwp-same-width-full-container' === container) {
                return {
                    'data-align': 'full'
                };
            } else if ('cwp-same-width-wide-container' === container) {
                return {
                    'data-align': 'wide'
                };
            }
        },
        edit: function(props) {
            var attributes = props.attributes;

			// auto ID
			if(attributes.blockAutoID === 'empty' || attributes.blockAutoID === undefined)
			{
				attributes.blockAutoID = 'cwp-fancy-container-'+(new Date()).getTime();
			}

			// override default params for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{
				attributes.paddingBeforeIntro = -1;
				attributes.paddingAfterIntro = -1;
				attributes.paddingAfterItems = -1;
				attributes.boxradius = -1;
				attributes.boxradiusfix = true;
				attributes.boxpadding = -1;
				attributes.boxpaddingfix = true;
				attributes.container = 'cwp-full-width-small-container';
			}
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}

            var solidColorPreset = el(ColorPalette, {
				value: attributes.solidColor,
				onChange: function(e) {
					props.setAttributes({
						solidColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#00d1b2",
					name: "teal"
				}, {
					color: "#3373dc",
					name: "royal blue"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			
			var fancyBackgroundSolidColorPreset = el(ColorPalette, {
				value: attributes.fancyBackgroundSolidColor,
				onChange: function(e) {
					props.setAttributes({
						fancyBackgroundSolidColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#00d1b2",
					name: "teal"
				}, {
					color: "#3373dc",
					name: "royal blue"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			
			var backgroundTextColorPreset = el(ColorPalette, {
				value: attributes.backgroundTextColor,
				onChange: function(e) {
					props.setAttributes({
						backgroundTextColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#333333",
					name: "dark"
				}, {
					color: "#000000",
					name: "black"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			var gradientPreset = el(SelectControl, {
				label: __('Gradients', 'cosmic-blocks'),
				options: gradient_options.map(function(e) {
					return {
						value: e.colors,
						label: e.name
					};
				}),
				value: attributes.gradient,
				onChange: function(e) {
					props.setAttributes({
						gradient: e
					});
				}
			});
			var fancyBackgroundGradientPreset = el(SelectControl, {
				label: __('Gradients', 'cosmic-blocks'),
				options: gradient_options.map(function(e) {
					return {
						value: e.colors,
						label: e.name
					};
				}),
				value: attributes.fancyBackgroundGradient,
				onChange: function(e) {
					props.setAttributes({
						fancyBackgroundGradient: e
					});
				}
			});
			var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_style_string = function() {
				var s = '';
				if (attributes.fancyBackgroundType === 'color' && attributes.fancyBackgroundSolidColor !== '' && attributes.fancyBackgroundSolidColor !== undefined) {
					s = 'background:' + attributes.fancyBackgroundSolidColor;
				} else if (attributes.fancyBackgroundType === 'gradient' && attributes.fancyBackgroundGradient !== '' && attributes.fancyBackgroundGradient !== undefined) {
					s = 'background: linear-gradient(to bottom, ' + attributes.fancyBackgroundGradient + ')';
				} else if (attributes.fancyBackgroundType === 'image' && attributes.fancyBackgroundMediaURL !== '' && attributes.fancyBackgroundMediaURL !== undefined) {
					s = 'background: url( ' + attributes.fancyBackgroundMediaURL + ' ); background-size: cover; background-position: center;';
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};
			var image_container_width = function() {
				var s = {};
				if (attributes.imageContainerWidth >= 0) {
					s.width = attributes.imageContainerWidth+'%';
				}
				if (attributes.imageContainerOffset === 'top' && attributes.imageContainerOffsetPx < 0) {
					s.top = attributes.imageContainerOffsetPx;
				}
				else if (attributes.imageContainerOffset === 'bottom' && attributes.imageContainerOffsetPx < 0) {
					s.bottom = attributes.imageContainerOffsetPx;
				}
				return s;
			};
			
            return [
                el(
                    Fragment,
                    null,
                    el(InspectorControls, {
                            key: 'inspector'
                        }, // Display the block options in the inspector panel.
						el(wp.components.PanelBody, {
								title: __('Intro', 'cosmic-blocks'),
								className: 'cwp-inspector-intro',
								initialOpen: false
							},
							el(SelectControl, {
								label: __('Enable/disable', 'cosmic-blocks'),
								value: attributes.introsection,
								options: [{
										label: __('Disabled', 'cosmic-blocks'),
										value: 'disabled'
									},
									{
										label: __('Enabled', 'cosmic-blocks'),
										value: 'enabled'
									}
								],
								onChange: function onChange(value) {
									props.setAttributes({
										introsection: value
									});
								}
							}),
							attributes.introsection === 'enabled' ? el('p', {}, __('Intro text color', 'cosmic-blocks')) : '',
							attributes.introsection === 'enabled' ? backgroundTextColorPreset : '',
							attributes.introsection === 'enabled' ? el(RangeControl, {
								label: __('Padding after intro text', 'cosmic-blocks'),
								value: attributes.paddingAfterIntro,
								allowReset: false,
								initialPosition: 50,
								onChange: function(e) {
									return props.setAttributes({
										paddingAfterIntro: e
									});
								},
								min: -1,
								max: 200
							}) : '',
						),
                        el(wp.components.PanelBody, {
                                title: __('Layout', 'cosmic-blocks'),
                                className: 'cwp-inspector-layout',
                                initialOpen: false
							},
                            el(SelectControl, {
                                label: __('Container width', 'cosmic-blocks'),
                                value: attributes.container,
                                options: container_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    props.setAttributes({
                                        container: e
                                    });
                                }
                            }),
                            el(RangeControl, {
                                label: __('Padding top', 'cosmic-blocks'),
                                value: attributes.paddingBeforeIntro,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingBeforeIntro: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el(RangeControl, {
                                label: __('Padding bottom', 'cosmic-blocks'),
                                value: attributes.paddingAfterItems,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingAfterItems: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el('p', {
                                className: 'cwp-custom-label'
                            }, __('Background', 'cosmic-blocks')),
                            el(ButtonGroup, {},
                                backgroundType.map(function(e) {
                                    return el(Button, {
                                        key: e.label,
                                        isLarge: !0,
                                        isPrimary: attributes.backgroundType === e.value,
                                        "aria-pressed": attributes.backgroundType === e.value,
										onClick: function() {
                                            return props.setAttributes({
                                                backgroundType: e.value
                                            });
                                        }
                                    }, e.label);
                                })
                            ),
                            "color" === attributes.backgroundType && solidColorPreset,
                            "gradient" === attributes.backgroundType && gradientPreset,
                            "image" === attributes.backgroundType && el(
                                MediaUpload, {
                                    key: "mediaupload",
                                    onSelect: function(media) {
                                        return props.setAttributes({
                                            backgroundMediaURL: media.url,
                                            backgroundMediaID: media.id
                                        });
                                    },
                                    type: "image",
                                    value: attributes.backgroundMediaID,
                                    render: function(e) {
                                        var r = e.open;
                                        return el(Fragment, null, el(Button, {
                                            className: "button-link cwp-custom-button",
                                            onClick: r
                                        }, attributes.backgroundMediaID ? el("img", {
                                            src: attributes.backgroundMediaURL
                                        }) : __('Set background image', 'cosmic-blocks')));
                                    }
                                }
                            ),
                            "image" === attributes.backgroundType && attributes.backgroundMediaID && el(Fragment, null, el("p", {
                                className: "cwp-custom-edit-image"
                            }, __('Click the image to edit or update', 'cosmic-blocks')), el(Button, {
                                className: "button-link",
                                style: {
                                    marginBottom: "20px"
                                },
                                onClick: function() {
                                    return props.setAttributes({
                                        backgroundMediaURL: void 0,
                                        backgroundMediaID: void 0
                                    });
                                }
                            }, __('Remove background image', 'cosmic-blocks'))),
                            el(TextControl, {
                                label: __('Block ID', 'cosmic-blocks'),
                                value: attributes.blockID,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        blockID: e
                                    });
                                }
                            }),
						),
						el(wp.components.PanelBody, {
								title: __('Block Settings', 'cosmic-blocks'),
								className: 'cwp-inspector-items',
								initialOpen: false
							},
							el(SelectControl, {
								label: __('Image Position', 'cosmic-blocks'),
                                value: attributes.imagePosition,
                                options: [{
                                        label: __('Left', 'cosmic-blocks'),
                                        value: 'cwp-image-left'
                                    },
                                    {
                                        label: __('Right', 'cosmic-blocks'),
                                        value: 'cwp-image-right'
                                    }
                                ],
                                onChange: function onChange(value) {
                                    props.setAttributes({
                                        imagePosition: value
                                    });
                                }
                            }),
							el(RangeControl, {
                                label: __('Image container width %', 'cosmic-blocks'),
                                value: attributes.imageContainerWidth,
                                allowReset: false,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        imageContainerWidth: e
                                    });
                                },
                                min: -1,
                                max: 100
                            }),
							el(SelectControl, {
								label: __('Image container offset', 'cosmic-blocks'),
                                value: attributes.imageContainerOffset,
                                options: [{
                                        label: __('No', 'cosmic-blocks'),
                                        value: 'no'
                                    },
                                    {
                                        label: __('Top', 'cosmic-blocks'),
                                        value: 'top'
                                    },
                                    {
                                        label: __('Bottom', 'cosmic-blocks'),
                                        value: 'bottom'
                                    }
                                ],
                                onChange: function onChange(value) {
                                    props.setAttributes({
                                        imageContainerOffset: value
                                    });
                                }
                            }),
							attributes.imageContainerOffset === 'top' || attributes.imageContainerOffset === 'bottom' ? el(RangeControl, {
                                label: __('Image container offset px', 'cosmic-blocks'),
                                value: attributes.imageContainerOffsetPx,
                                allowReset: false,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        imageContainerOffsetPx: e
                                    });
                                },
                                min: -250,
                                max: 0
                            }) : '',
							el('hr'),
							el(SelectControl, {
								label: __('Image container thumbnail size', 'cosmic-blocks'),
                                value: attributes.thumbnailSize,
                                options: thumbnail_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(value) {
                                    var thumb = value;
                                    jQuery.post(ajaxurl, {
                                        action: 'cosmic_blocks_thumbnail_helper_single',
                                        thumb: thumb,
                                        mediaID: attributes.mediaID
                                    }, function(response) {
										attributes.mediaURL = (response.thumb.src !== '' && response.thumb.src !== undefined) ? response.thumb.src : response.full.src;
                                        return props.setAttributes({
                                            thumbnailSize: thumb
                                        });
                                    }, 'json');
                                }
                            }),
							el('p', {
                                className: 'cwp-custom-label'
                            }, __('Animated background', 'cosmic-blocks')),
                            el(ButtonGroup, {},
                                backgroundType.map(function(e) {
                                    return el(Button, {
                                        key: e.label,
                                        isLarge: !0,
                                        isPrimary: attributes.fancyBackgroundType === e.value,
                                        "aria-pressed": attributes.fancyBackgroundType === e.value,
                                        onClick: function() {
                                            return props.setAttributes({
                                                fancyBackgroundType: e.value
                                            });
                                        }
                                    }, e.label);
                                })
                            ),
                            "color" === attributes.fancyBackgroundType && fancyBackgroundSolidColorPreset,
                            "gradient" === attributes.fancyBackgroundType && fancyBackgroundGradientPreset,
                            "image" === attributes.fancyBackgroundType && el(
                                MediaUpload, {
                                    key: "mediaupload",
                                    onSelect: function(media) {
                                        return props.setAttributes({
                                            fancyBackgroundMediaURL: media.url,
                                            fancyBackgroundMediaID: media.id
                                        });
                                    },
                                    type: "image",
                                    value: attributes.fancyBackgroundMediaID,
                                    render: function(e) {
                                        var r = e.open;
                                        return el(Fragment, null, el(Button, {
                                            className: "button-link cwp-custom-button",
                                            onClick: r
                                        }, attributes.fancyBackgroundMediaID ? el("img", {
                                            src: attributes.fancyBackgroundMediaURL
                                        }) : __('Set fancy background image', 'cosmic-blocks')));
                                    }
                                }
                            ),
                            "image" === attributes.fancyBackgroundType && attributes.fancyBackgroundMediaID && el(Fragment, null, el("p", {
                                className: "cwp-custom-edit-image"
                            }, __('Click the image to edit or update', 'cosmic-blocks')), el(Button, {
                                className: "button-link",
                                style: {
                                    marginBottom: "20px"
                                },
                                onClick: function() {
                                    return props.setAttributes({
                                        fancyBackgroundMediaURL: void 0,
                                        fancyBackgroundMediaID: void 0
                                    });
                                }
                            }, __('Remove background image', 'cosmic-blocks'))),
							el(SelectControl, {
								label: __('Image background width', 'cosmic-blocks'),
                                value: attributes.animatedContainerWidth,
                                options: [{
                                        label: __('Auto (half of image)', 'cosmic-blocks'),
                                        value: 'auto'
                                    },
                                    {
                                        label: __('Custom', 'cosmic-blocks'),
                                        value: 'custom'
                                    }
                                ],
                                onChange: function onChange(value) {
                                    props.setAttributes({
                                        animatedContainerWidth: value
                                    });
                                }
                            }),
							attributes.animatedContainerWidth === 'custom' ? el(RangeControl, {
                                label: __('Animated background width %', 'cosmic-blocks'),
                                value: attributes.animatedContainerWidthPx,
                                allowReset: false,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animatedContainerWidthPx: e
                                    });
                                },
                                min: -1,
                                max: 100
                            }) : '',
						),
                        el(wp.components.PanelBody, {
                                title: __('Animation', 'cosmic-blocks'),
                                className: 'cwp-inspector-animation',
                                initialOpen: false
                            },
                            el(SelectControl, {
								label: __('Animation', 'cosmic-blocks'),
                                value: attributes.animationStyle,
                                options: animation_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationStyle: e
                                    });
                                }
                            }),
                            el(TextControl, {
								label: __('Animation Delay', 'cosmic-blocks'),
                                value: attributes.animationDelay,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationDelay: e
                                    });
                                },
                                help: __('Enter in milliseconds', 'cosmic-blocks')
                            }),
                            el(RangeControl, {
                                beforeIcon: 'arrow-left-alt2',
                                afterIcon: 'arrow-right-alt2',
                                label: __('Threshold', 'cosmic-blocks'),
                                value: attributes.threshold,
                                allowReset: false,
                                initialPosition: 40,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        threshold: e
                                    });
                                },
                                min: 0,
                                max: 100
                            }),
                        )
                    ),
                    el('div', {
							id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + 'cwp-calc-' + attributes.animatedContainerWidth + ' ' + attributes.imagePosition + ' ' + attributes.container + ' cwp-common-main-wrap ' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
							style: back_style()
                        },
						el('style', {},
							'.wp-block-cwp-container-fancy-animated #' + attributes.blockAutoID + ' .cwp-main-wrapper::before { ' + back_style_string() + ' }',
							attributes.animatedContainerWidth === 'custom' && (attributes.animatedContainerWidthPx >= 0 && attributes.imagePosition === 'cwp-image-left') ? '.wp-block-cwp-container-fancy-animated.cwp-image-left #' + attributes.blockAutoID + ' .cwp-main-wrapper.cwp-visible::before { left:' + attributes.animatedContainerWidthPx + '% }' : '',
							attributes.animatedContainerWidth === 'custom' && (attributes.animatedContainerWidthPx >= 0 && attributes.imagePosition === 'cwp-image-right') ? '.wp-block-cwp-container-fancy-animated.cwp-image-right #' + attributes.blockAutoID + ' .cwp-main-wrapper.cwp-visible::before { right:' + attributes.animatedContainerWidthPx + '% }' : '',
						),
						el('style', {
								className: 'cwp-auto-calc-settings'
							}
						),
                        el('div', {
								id: (attributes.blockAutoID !== '' && attributes.blockAutoID !== undefined ? attributes.blockAutoID : ''),
                                className: 'cwp-common-main-wrap-inner' + (attributes.animationStyle !== '' && attributes.animationStyle !== undefined ? ' animated ' + attributes.animationStyle : ''),
                                style: box_padding()
                            },
                            attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
                                    style: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'h3',
                                            placeholder: __('Title', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introtitle,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
											allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introtitle: e
                                                });
                                            }
                                        })
                                    )
                                ),
                                el('div', {
                                        className: 'cwp-intro-subtitle'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Subtitle', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introsubtitle,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
											allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introsubtitle: e
                                                });
                                            }
                                        })
                                    )
                                ),
                                el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Introduction', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introduction,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
											allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introduction: e
                                                });
                                            }
                                        })
                                    )
                                )
                            ) : '',
							el('div', {
									className: 'cwp-main-wrapper cwp-visible'
								},
								el('div', {
										className: 'cwp-inner-block-shell'
									},
									el('div', {
											className: 'cwp-inner-block-image cwp-visible',
											style: image_container_width()
										},
										el('div', {
												className: attributes.mediaID ? 'cwp-image image-active' : 'cwp-image image-inactive'
											},
											el(MediaUpload, {
												onSelect: function(media) {
													if (media.id !== '' && media.id !== undefined) {
														wp.apiFetch({
															path: "/wp/v2/media/" + media.id
														}).then((response) => {
															var newMediaUrl = response.media_details.sizes.full.source_url;
															if (response.media_details.sizes[attributes.thumbnailSize] !== '' && response.media_details.sizes[attributes.thumbnailSize] !== undefined) {
																newMediaUrl = response.media_details.sizes[attributes.thumbnailSize].source_url;
															}

															return props.setAttributes({
																mediaID: media.id,
																mediaURL: newMediaUrl
															});
														});
													}
												},
												type: 'image',
												value: attributes.mediaID,
												render: function(obj) {
													if (attributes.mediaID !== '' && attributes.mediaID !== undefined) {
														return el(wp.components.Button, {
															className: 'image-button',
															onClick: obj.open
														}, el('img', {
															src: attributes.mediaURL
														}));
													} else {
														return el(wp.components.Button, {
															className: 'button button-large',
															onClick: obj.open
														}, __('Upload Image', 'cosmic-blocks'));
													}
												}
											}),
											attributes.mediaID && el('div', {
													className: 'remove-image',
													title: __('Remove Image', 'cosmic-blocks'),
													onClick: function() {
														if (confirm(__('Are you sure?', 'cosmic-blocks'))) {
															return props.setAttributes({
																mediaID: void 0,
																mediaURL: void 0
															});
														}
													}
												},
												el('span', {
													className: "dashicons dashicons-no-alt"
												})
											)
										)
									),
									el('div', {
											className: 'cwp-inner-block-container'
										},
										el(InnerBlocks)
									)
								)
							)
                        )
                    )
                )
            ];
        },
        save: function(props) {
			var attributes = props.attributes;
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}
			
			var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_style_string = function() {
				var s = '';
				if (attributes.fancyBackgroundType === 'color' && attributes.fancyBackgroundSolidColor !== '' && attributes.fancyBackgroundSolidColor !== undefined) {
					s = 'background:' + attributes.fancyBackgroundSolidColor;
				} else if (attributes.fancyBackgroundType === 'gradient' && attributes.fancyBackgroundGradient !== '' && attributes.fancyBackgroundGradient !== undefined) {
					s = 'background: linear-gradient(to bottom, ' + attributes.fancyBackgroundGradient + ')';
				} else if (attributes.fancyBackgroundType === 'image' && attributes.fancyBackgroundMediaURL !== '' && attributes.fancyBackgroundMediaURL !== undefined) {
					s = 'background: url( ' + attributes.fancyBackgroundMediaURL + ' ); background-size: cover; background-position: center;';
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};
			var image_container_width = function() {
				var s = {};
				if (attributes.imageContainerWidth >= 0) {
					s.width = attributes.imageContainerWidth+'%';
				}
				if (attributes.imageContainerOffset === 'top' && attributes.imageContainerOffsetPx < 0) {
					s.top = attributes.imageContainerOffsetPx;
				}
				else if (attributes.imageContainerOffset === 'bottom' && attributes.imageContainerOffsetPx < 0) {
					s.bottom = attributes.imageContainerOffsetPx;
				}
				return s;
			};
			
			return el('div', {
					id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                    className: 'cwp-common-main-wrap' + ' ' + 'cwp-calc-' + attributes.animatedContainerWidth + ' ' + attributes.imagePosition + ' ' + attributes.container + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                    style: back_style()
                },
				el('style', {},
					'.wp-block-cwp-container-fancy-animated #' + attributes.blockAutoID + ' .cwp-main-wrapper::before { ' + back_style_string() + ' }',
					attributes.animatedContainerWidth === 'custom' && (attributes.animatedContainerWidthPx >= 0 && attributes.imagePosition === 'cwp-image-left') ? '.wp-block-cwp-container-fancy-animated.' + attributes.imagePosition + ' #' + attributes.blockAutoID + ' .cwp-main-wrapper.cwp-visible::before { left:' + attributes.animatedContainerWidthPx + '% }' : '',
					attributes.animatedContainerWidth === 'custom' && (attributes.animatedContainerWidthPx >= 0 && attributes.imagePosition === 'cwp-image-right') ? '.wp-block-cwp-container-fancy-animated.' + attributes.imagePosition + ' #' + attributes.blockAutoID + ' .cwp-main-wrapper.cwp-visible::before { right:' + attributes.animatedContainerWidthPx + '% }' : '',
				),
				el('style', {
						className: 'cwp-auto-calc-settings'
					}
				),
                el('div', {
						id: (attributes.blockAutoID !== '' && attributes.blockAutoID !== undefined ? attributes.blockAutoID : ''),
                        className: 'cwp-common-main-wrap-inner',
                        style: box_padding(),
                        "data-scroll-class": attributes.animationStyle,
                        "data-scroll-delay": attributes.animationDelay,
                        "data-scroll-threshold": attributes.threshold
                    },
                    attributes.introsection === 'enabled' ? el('div', {
                            className: 'cwp-main-intro',
                            style: attributes.paddingAfterIntro >= 0 ? {
								paddingBottom: attributes.paddingAfterIntro
							} : {}
                        },
                        (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
                                className: 'cwp-intro-title'
                            },
                            el('h3', {
                                    style: back_text_style()
                                },
                                (attributes.introtitle !== '' && attributes.introtitle !== undefined) ? el(
                                    RichText.Content, {
                                        tagName: '',
                                        value: attributes.introtitle
                                    }
                                ) : '',
                                (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el(
                                    RichText.Content, {
                                        tagName: 'span',
                                        value: attributes.introsubtitle
                                    }
                                ) : '',
                            ),
                        ) : '',
                        (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                                className: 'cwp-intro-introduction'
                            },
                            el('div', {
                                    className: 'cwp-intro-input'
                                },
                                el(
                                    RichText.Content, {
                                        tagName: 'p',
                                        value: attributes.introduction,
                                        style: back_text_style()
                                    }
                                ),
                            ),
                        ) : '',
                    ) : '',
					el('div', {
							className: 'cwp-main-wrapper'
						},
						el('div', {
								className: 'cwp-inner-block-shell'
							},
							el('div', {
									className: 'cwp-inner-block-image',
									style: image_container_width()
								},
								el('img', {
									src: attributes.mediaURL
								})
							),
							el('div', {
									className: 'cwp-inner-block-container'
								},
								el(InnerBlocks.Content)
							)
						)
					)
                )
            );
        }
    });
})(
    window.wp
);