(function(wp) {
    var el = wp.element.createElement;
    var InspectorControls = wp.blockEditor.InspectorControls;
    var RichText = wp.blockEditor.RichText;
    var Fragment = wp.element.Fragment;
    var MediaUpload = wp.blockEditor.MediaUpload;
    var TextControl = wp.components.TextControl;
    var RangeControl = wp.components.RangeControl;
	var CheckboxControl = wp.components.ToggleControl;
    var SelectControl = wp.components.SelectControl;
    var ButtonGroup = wp.components.ButtonGroup;
    var Button = wp.components.Button;
    var ColorPalette = wp.components.ColorPalette;
    var __ = wp.i18n.__;
    var _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };

    function _LinkMove(e, t, n) {
        var r = e.slice(0);
        if (n >= r.length) {
            for (var o = n - r.length; 1 + o--;) {
                r.push(void 0);
            }
        }
        return r.splice(n, 0, r.splice(t, 1)[0]), r;
    }

    wp.blocks.registerBlockType('cwp/countdown', {
        title: __('Countdown', 'cosmic-blocks'),
		keywords: [
			'countdown',
			__('count down', 'cosmic-blocks'),
			__('timer', 'cosmic-blocks')
		],
        icon: {
			background: "#16A3FF",
			foreground: "#FFFFFF",
			src: "clock"
		},
        category: 'cwp-blocks',
        attributes: {
			blockID: {
				type: 'string',
				default: ''
			},
            columns: {
                type: "number",
                default: 1
            },
            container: {
                type: "string",
                default: 'cwp-full-width-wide-container'
            },
			positionClass: {
                type: "string",
                default: 'cwp-all-center'
            },
            backgroundType: {
                type: "string",
                default: 'color'
            },
			backgroundTextColor: {
				type: "string",
                default: ''
			},
            solidColor: {
                type: "string",
                default: ''
            },
            gradient: {
                type: "string"
            },
            backgroundMediaID: {
                type: "number"
            },
            backgroundMediaURL: {
                type: "string"
            },
            animationStyle: {
                type: "string"
            },
            animationDelay: {
                type: "number",
                default: 10
            },
            threshold: {
                type: "number",
                default: 40
            },
			paddingBeforeIntro: {
				type: 'number',
				default: 50
			},
			paddingAfterIntro: {
				type: 'number',
				default: 50
			},
			paddingAfterItems: {
				type: 'number',
				default: 50
			},
			introsection: {
                type: 'string',
                default: 'empty'
            },
            introtitle: {
                type: "string",
                default: ''
            },
            introsubtitle: {
                type: "string",
                default: ''
            },
            introduction: {
                type: "string",
                default: ''
            },
			boxradius: {
                type: "number",
                default: 0
            },
			boxradiusfix: {
				type: 'boolean',
				default: false
			},
            boxpadding: {
                type: "number",
                default: 0
            },
			boxpaddingfix: {
				type: 'boolean',
				default: false
			},
			Textyears: {
                type: "string",
                default: 'Years'
            },
			Textmonths: {
                type: "string",
                default: 'Months'
            },
			Textdays: {
                type: "string",
                default: 'Days'
            },
			Texthours: {
                type: "string",
                default: 'Hours'
            },
			Textminutes: {
                type: "string",
                default: 'Minutes'
            },
			Textseconds: {
                type: "string",
                default: 'Seconds'
            },
			showYears: {
				type: "boolean",
				default: true
			},
			showMonths: {
				type: "boolean",
				default: true
			},
			showDays: {
				type: "boolean",
				default: true
			},
			showHours: {
				type: "boolean",
				default: true
			},
			showMinutes: {
				type: "boolean",
				default: true
			},
			showSeconds: {
				type: "boolean",
				default: true
			},
            link: {
                type: 'array',
                default: [{
                    date: "",
					text: "",
					color: "",
                    textcolor: "",
					boxcolor: "",
					boxbgcolor: ""
                }]
            }
        },
		getEditWrapperProps({
            container
        }) {
            if ('cwp-full-width-wide-container' === container || 'cwp-full-width-small-container' === container || 'cwp-same-width-full-container' === container) {
                return {
                    'data-align': 'full'
                };
            } else if ('cwp-same-width-wide-container' === container) {
                return {
                    'data-align': 'wide'
                };
            }
        },
        edit: function(props) {
            var attributes = props.attributes;
			
			// override default params for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{
				attributes.paddingBeforeIntro = -1;
				attributes.paddingAfterIntro = -1;
				attributes.paddingAfterItems = -1;
				attributes.boxradius = -1;
				attributes.boxradiusfix = true;
				attributes.boxpadding = -1;
				attributes.boxpaddingfix = true;
				attributes.container = 'cwp-full-width-small-container';
			}
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}
			
            var items = attributes.link;
            var cwpUpdateLink = function(value, index) {
                var _props2 = props;
                var attributes = _props2.attributes;
                var setAttributes = _props2.setAttributes;
                var items = attributes.link;

                var newItems = items.map(function(item, thisIndex) {
                    if (index === thisIndex) {
                        item = _extends({}, item, value);
                    }
                    return item;
                });

                setAttributes({
                    link: newItems
                });
            };

            var solidColorPreset = el(ColorPalette, {
				value: attributes.solidColor,
				onChange: function(e) {
					props.setAttributes({
						solidColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#00d1b2",
					name: "teal"
				}, {
					color: "#3373dc",
					name: "royal blue"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			var backgroundTextColorPreset = el(ColorPalette, {
				value: attributes.backgroundTextColor,
				onChange: function(e) {
					props.setAttributes({
						backgroundTextColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#333333",
					name: "dark"
				}, {
					color: "#000000",
					name: "black"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			var gradientPreset = el(SelectControl, {
				label: __('Gradients', 'cosmic-blocks'),
				options: gradient_options.map(function(e) {
					return {
						value: e.colors,
						label: e.name
					};
				}),
				value: attributes.gradient,
				onChange: function(e) {
					props.setAttributes({
						gradient: e
					});
				}
			});
			var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var box_style = function() {
				var s = {};
				if(attributes.boxradiusfix === true && attributes.boxradius >= 0)
				{
					s.borderRadius = attributes.boxradius;
				}
				else if(attributes.boxradius > 0)
				{
					s.borderRadius = attributes.boxradius;
				}
				if(attributes.boxpaddingfix === true && attributes.boxpadding >= 0)
				{
					s.padding = attributes.boxpadding;
				}
				else if(attributes.boxpadding > 0)
				{
					s.padding = attributes.boxpadding;
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};

            return [
                el(
                    Fragment,
                    null,
                    el(InspectorControls, {
                            key: 'inspector'
                        }, // Display the block options in the inspector panel.
						el(wp.components.PanelBody, {
								title: __('Intro', 'cosmic-blocks'),
								className: 'cwp-inspector-intro',
								initialOpen: false
							},
							el(SelectControl, {
								label: __('Enable/disable', 'cosmic-blocks'),
								value: attributes.introsection,
								options: [{
										label: __('Disabled', 'cosmic-blocks'),
										value: 'disabled'
									},
									{
										label: __('Enabled', 'cosmic-blocks'),
										value: 'enabled'
									}
								],
								onChange: function onChange(value) {
									props.setAttributes({
										introsection: value
									});
								}
							}),
							attributes.introsection === 'enabled' ? el('p', {}, __('Intro text color', 'cosmic-blocks')) : '',
							attributes.introsection === 'enabled' ? backgroundTextColorPreset : '',
							attributes.introsection === 'enabled' ? el(RangeControl, {
								label: __('Padding after intro text', 'cosmic-blocks'),
								value: attributes.paddingAfterIntro,
								allowReset: false,
								initialPosition: 50,
								onChange: function(e) {
									return props.setAttributes({
										paddingAfterIntro: e
									});
								},
								min: -1,
								max: 200
							}) : '',
						),
                        el(wp.components.PanelBody, {
                                title: __('Layout', 'cosmic-blocks'),
                                className: 'cwp-inspector-layout',
                                initialOpen: false
							},
                            el(SelectControl, {
                                label: __('Container width', 'cosmic-blocks'),
                                value: attributes.container,
                                options: container_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    props.setAttributes({
                                        container: e
                                    });
                                }
                            }),
                            el(RangeControl, {
                                label: __('Padding top', 'cosmic-blocks'),
                                value: attributes.paddingBeforeIntro,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingBeforeIntro: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el(RangeControl, {
                                label: __('Padding bottom', 'cosmic-blocks'),
                                value: attributes.paddingAfterItems,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingAfterItems: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el('p', {
                                className: 'cwp-custom-label'
                            }, __('Background', 'cosmic-blocks')),
                            el(ButtonGroup, {},
                                backgroundType.map(function(e) {
                                    return el(Button, {
                                        key: e.label,
                                        isLarge: !0,
                                        isPrimary: attributes.backgroundType === e.value,
                                        "aria-pressed": attributes.backgroundType === e.value,
                                        onClick: function() {
                                            return props.setAttributes({
                                                backgroundType: e.value
                                            });
                                        }
                                    }, e.label);
                                })
                            ),
                            "color" === attributes.backgroundType && solidColorPreset,
                            "gradient" === attributes.backgroundType && gradientPreset,
                            "image" === attributes.backgroundType && el(
                                MediaUpload, {
                                    key: "mediaupload",
                                    onSelect: function(media) {
                                        return props.setAttributes({
                                            backgroundMediaURL: media.url,
                                            backgroundMediaID: media.id
                                        });
                                    },
                                    type: "image",
                                    value: attributes.backgroundMediaID,
                                    render: function(e) {
                                        var r = e.open;
                                        return el(Fragment, null, el(Button, {
                                            className: "button-link cwp-custom-button",
                                            onClick: r
                                        }, attributes.backgroundMediaID ? el("img", {
                                            src: attributes.backgroundMediaURL
                                        }) : __('Set background image', 'cosmic-blocks')));
                                    }
                                }
                            ),
                            "image" === attributes.backgroundType && attributes.backgroundMediaID && el(Fragment, null, el("p", {
                                className: "cwp-custom-edit-image"
                            }, __('Click the image to edit or update', 'cosmic-blocks')), el(Button, {
                                className: "button-link",
                                style: {
                                    marginBottom: "20px"
                                },
                                onClick: function() {
                                    return props.setAttributes({
                                        backgroundMediaURL: void 0,
                                        backgroundMediaID: void 0
                                    });
                                }
                            }, __('Remove background image', 'cosmic-blocks'))),
                            el(TextControl, {
                                label: __('Block ID', 'cosmic-blocks'),
                                value: attributes.blockID,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        blockID: e
                                    });
                                }
                            }),
						),
						el(wp.components.PanelBody, {
								title: __('Items', 'cosmic-blocks'),
								className: 'cwp-inspector-items',
								initialOpen: true
							},
							el(CheckboxControl, {
								label: __('Show years', 'cosmic-blocks'),
								checked: attributes.showYears,
								onChange: function(e) {
									return props.setAttributes({
										showYears: e
									});
								}
							}),
							el(CheckboxControl, {
								label: __('Show months', 'cosmic-blocks'),
								checked: attributes.showMonths,
								onChange: function(e) {
									return props.setAttributes({
										showMonths: e
									});
								}
							}),
							el(CheckboxControl, {
								label: __('Show days', 'cosmic-blocks'),
								checked: attributes.showDays,
								onChange: function(e) {
									return props.setAttributes({
										showDays: e
									});
								}
							}),
							el(CheckboxControl, {
								label: __('Show hours', 'cosmic-blocks'),
								checked: attributes.showHours,
								onChange: function(e) {
									return props.setAttributes({
										showHours: e
									});
								}
							}),
							el(CheckboxControl, {
								label: __('Show minutes', 'cosmic-blocks'),
								checked: attributes.showMinutes,
								onChange: function(e) {
									return props.setAttributes({
										showMinutes: e
									});
								}
							}),
							el(CheckboxControl, {
								label: __('Show seconds', 'cosmic-blocks'),
								checked: attributes.showSeconds,
								onChange: function(e) {
									return props.setAttributes({
										showSeconds: e
									});
								}
							}),
							el(SelectControl, {
								label: __('Position', 'cosmic-blocks'),
								value: attributes.positionClass,
								options: [{
										label: __('Left', 'cosmic-blocks'),
										value: 'cwp-all-left'
									},
									{
										label: __('Center', 'cosmic-blocks'),
										value: 'cwp-all-center'
									},
									{
										label: __('Right', 'cosmic-blocks'),
										value: 'cwp-all-right'
									}
								],
								onChange: function onChange(value) {
									props.setAttributes({
                                        positionClass: value
                                    });
								}
							}),
							el(RangeControl, {
								label: __('Items border radius', 'cosmic-blocks'),
								value: attributes.boxradius,
								onChange: function(e) {
									return props.setAttributes({
										boxradius: e,
										boxradiusfix: true
									});
								},
								min: -1,
								max: 50
							}),
							el(RangeControl, {
								label: __('Items padding', 'cosmic-blocks'),
								value: attributes.boxpadding,
								onChange: function(e) {
									return props.setAttributes({
										boxpadding: e,
										boxpaddingfix: true
									});
								},
								min: -1,
								max: 50
							})
						),
                        el(wp.components.PanelBody, {
                                title: 'Animation',
                                className: 'cwp-inspector-animation',
                                initialOpen: false
                            },
                            el('p', {}, 'Animation'),
                            el(SelectControl, {
                                value: attributes.animationStyle,
                                options: animation_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationStyle: e
                                    });
                                }
                            }),
                            el('p', {}, 'Animation Delay'),
                            el(TextControl, {
                                value: attributes.animationDelay,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationDelay: e
                                    });
                                },
                                help: 'Enter in milliseconds'
                            }),
                            el(RangeControl, {
                                beforeIcon: 'arrow-left-alt2',
                                afterIcon: 'arrow-right-alt2',
                                label: __('Threshold', 'cosmic-blocks'),
                                value: attributes.threshold,
								allowReset: false,
								initialPosition: 40,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        threshold: e
                                    });
                                },
                                min: 0,
                                max: 100
                            }),
                        )
                    ),
                    el('div', {
							id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-backend-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
							style: back_style()
                        },
                        el('div', {
								className: 'cwp-common-main-wrap-inner' + (attributes.animationStyle !== '' && attributes.animationStyle !== undefined ? ' animated ' + attributes.animationStyle : ''),
								style: box_padding()
                            },
                            attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
									style: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'h3',
                                            placeholder: __('Title', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introtitle,
											style: back_text_style(),
                                            isSelected: attributes.isSelected,
											allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-subtitle'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Subtitle', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introsubtitle,
											style: back_text_style(),
                                            isSelected: attributes.isSelected,
											allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introsubtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Introduction', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introduction,
											style: back_text_style(),
                                            isSelected: attributes.isSelected,
											allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introduction: e
                                                });
                                            }
                                        }),
                                    ),
                                )
                            ) : '',
                            el('div', {
                                    className: 'cwp-main-wrapper cwp-main-wrapper-single cwp-' + attributes.columns + '-column ' + attributes.positionClass
                                },
                                items.map(function(item, index) {
                                    localStorage.setItem('countdown_date', item.date);
									var block_back_style = function() {
										var s = {};
										if(item.color !== '' && item.color !== undefined) {
											s = {
												background: item.color
											};
										}
                                        return s;
                                    };
                                    var block_text_style = function() {
										var s = {};
										if(item.textcolor !== '' && item.textcolor !== undefined) {
											s = {
												color: item.textcolor
											};
										}
                                        return s;
                                    };
									var block_border_and_text_style = function() {
										var s = {};
										if(item.textcolor !== '' && item.textcolor !== undefined) {
											s = {
												color: item.textcolor,
												borderColor: item.textcolor
											};
										}
										return s;
									};
									var box_back_style = function() {
										var s = {};
										if(item.boxbgcolor !== '' && item.boxbgcolor !== undefined) {
											s = {
												background: item.boxbgcolor
											};
										}
                                        return s;
                                    };
									var box_text_style = function() {
										var s = {};
										if(item.boxcolor !== '' && item.boxcolor !== undefined) {
											s = {
												color: item.boxcolor
											};
										}
										return s;
									};
                                    return el(
                                        Fragment, {
                                            key: index
                                        },
                                        el('div', {
                                                className: 'cwp-inner-wrap'
                                            },
                                            el('div', {
                                                    className: 'cwp-meta-options'
                                                },
                                                el('div', {
                                                        className: 'cwp-element-bgcolor-main'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-drag-item cwp-option-bgcolor'
                                                        },
                                                        el('i', {
                                                            className: 'fa fa-paint-brush'
                                                        }),
                                                        el(ColorPalette, {
                                                            value: item.color,
                                                            onChange: function(e) {
                                                                return cwpUpdateLink({
                                                                    color: e
                                                                }, index);
                                                            }
                                                        })
                                                    )
                                                ),
                                                el('div', {
                                                        className: 'cwp-element-textcolor-main'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-drag-item cwp-option-textcolor'
                                                        },
                                                        el('i', {
                                                            className: 'fa fa-font',
                                                            style: block_text_style()
                                                        }),
                                                        el(ColorPalette, {
                                                            value: item.textcolor,
                                                            onChange: function(e) {
                                                                return cwpUpdateLink({
                                                                    textcolor: e
                                                                }, index);
                                                            }
                                                        })
                                                    )
                                                )
                                            ),
                                            el('div', {
                                                    className: 'cwp-content-wrap' + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : ''),
													style: box_back_style()
                                                },
												item.date !== '' && item.date !== undefined ? el('div', {
                                                        className: 'countdown-timer',
                                                        "data-time": item.date
                                                    },
                                                    el('div', {
                                                            className: "clockdiv"
                                                        },
                                                        /* Print years */
                                                        attributes.showYears === true ? el('div', {
                                                                className: 'main-countdown-years',
																style: Object.assign(block_back_style(), block_text_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-years',
																	style: block_border_and_text_style()
                                                                }
                                                            ),
															el(RichText, {
																tagName: 'div',
																className: 'smalltext',
																placeholder: __('Years', 'cosmic-wp'),
																keepPlaceholderOnFocus: true,
																value: attributes.Textyears,
																style: block_text_style(),
																isSelected: attributes.isSelected,
																allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
																onChange: function onChange(value) {
																	props.setAttributes({
																		Textyears: value
																	});
																}
															})
                                                        ) : '',
                                                        /* Print Months */
                                                        attributes.showMonths === true ? el('div', {
                                                                className: 'main-countdown-months',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-months',
																	style: block_border_and_text_style()
                                                                },
                                                            ),
															el(RichText, {
																tagName: 'div',
																className: 'smalltext',
																placeholder: __('Months', 'cosmic-wp'),
																keepPlaceholderOnFocus: true,
																value: attributes.Textmonths,
																style: block_text_style(),
																isSelected: attributes.isSelected,
																allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
																onChange: function onChange(value) {
																	props.setAttributes({
																		Textmonths: value
																	});
																}
															})
                                                        ) : '',
                                                        /* Print Days */
                                                        attributes.showDays === true ? el('div', {
                                                                className: 'main-countdown-days',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-days',
																	style: block_border_and_text_style()
                                                                },
                                                            ),
															el(RichText, {
																tagName: 'div',
																className: 'smalltext',
																placeholder: __('Days', 'cosmic-wp'),
																keepPlaceholderOnFocus: true,
																value: attributes.Textdays,
																style: block_text_style(),
																isSelected: attributes.isSelected,
																allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
																onChange: function onChange(value) {
																	props.setAttributes({
																		Textdays: value
																	});
																}
															})
                                                        ) : '',
                                                        /* Print Hours */
                                                        attributes.showHours === true ? el('div', {
                                                                className: 'main-countdown-hours',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-hours',
																	style: block_border_and_text_style()
                                                                },
                                                            ),
															el(RichText, {
																tagName: 'div',
																className: 'smalltext',
																placeholder: __('Hours', 'cosmic-wp'),
																keepPlaceholderOnFocus: true,
																value: attributes.Texthours,
																style: block_text_style(),
																isSelected: attributes.isSelected,
																allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
																onChange: function onChange(value) {
																	props.setAttributes({
																		Texthours: value
																	});
																}
															})
                                                        ) : '',
                                                        /* Print Minutes */
                                                        attributes.showMinutes === true ? el('div', {
                                                                className: 'main-countdown-minutes',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-minutes',
																	style: block_border_and_text_style()
                                                                },
                                                            ),
															el(RichText, {
																tagName: 'div',
																className: 'smalltext',
																placeholder: __('Minutes', 'cosmic-wp'),
																keepPlaceholderOnFocus: true,
																value: attributes.Textminutes,
																style: block_text_style(),
																isSelected: attributes.isSelected,
																allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
																onChange: function onChange(value) {
																	props.setAttributes({
																		Textminutes: value
																	});
																}
															})
                                                        ) : '',
                                                        /* Print seconds */
                                                        attributes.showSeconds === true ? el('div', {
                                                                className: 'main-countdown-seconds',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-seconds',
																	style: block_border_and_text_style()
                                                                }
                                                            ),
															el(RichText, {
																tagName: 'div',
																className: 'smalltext',
																placeholder: __('Seconds', 'cosmic-wp'),
																keepPlaceholderOnFocus: true,
																value: attributes.Textseconds,
																style: block_text_style(),
																isSelected: attributes.isSelected,
																allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
																onChange: function onChange(value) {
																	props.setAttributes({
																		Textseconds: value
																	});
																}
															})
                                                        ) : ''
                                                    )
												) : '',
												el('div', {
														className: 'cwp-color-select'
													},
													el('div', {
															className: 'cwp-color-select-label',
															title: __('Icon Color Settings', 'cosmic-blocks')
														},
														__('Item Color Settings', 'cosmic-blocks')
													),
													el('div', {
															className: 'cwp-color-select-item cwp-color-select-bgcolor'
														},
														el('i', {
															className: 'fa fa-paint-brush'
														}),
														el(ColorPalette, {
															value: item.color,
															onChange: function(e) {
																return cwpUpdateLink({
																	color: e
																}, index);
															}
														})
													),
													el('div', {
															className: 'cwp-color-select-item cwp-color-select-textcolor'
														},
														el('i', {
															className: 'fa fa-font'
														}),
														el(ColorPalette, {
															value: item.textcolor,
															onChange: function(e) {
																return cwpUpdateLink({
																	textcolor: e
																}, index);
															}
														})
													)
												),
                                                el(TextControl, {
                                                    type: "date",
                                                    value: item.date,
                                                    onChange: function onChange(value) {
                                                        return cwpUpdateLink({
                                                            date: value
                                                        }, index);
                                                    }
                                                }),
												el(RichText, {
													tagName: 'p',
													placeholder: 'Dolor quasi repellendus autem asperiores. Magnam veniam dolores ex.',
													keepPlaceholderOnFocus: true,
													value: item.text,
													style: box_text_style(),
													isSelected: attributes.isSelected,
													allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
													onChange: function onChange(value) {
                                                        return cwpUpdateLink({
                                                            text: value
                                                        }, index);
                                                    }
												})
                                            )
                                        )
                                    );
                                })
                            )
                        )
                    ),
                    el('div', {
							id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-front-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
							style: back_style()
                        },
                        el('div', {
								className: 'cwp-common-main-wrap-inner',
								style: box_padding(),
                                "data-scroll-class": attributes.animationStyle,
                                "data-scroll-delay": attributes.animationDelay,
                                "data-scroll-threshold": attributes.threshold
                            },
                            attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
									style: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('h3', {
											style: back_text_style()
										},
										(attributes.introtitle !== '' && attributes.introtitle !== undefined) ? el(
											RichText.Content, {
												tagName: '',
												value: attributes.introtitle
											}
										) : '',
										(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el(
											RichText.Content, {
												tagName: 'span',
												value: attributes.introsubtitle
											}
										) : '',
									),
								) : '',
                                (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(
                                            RichText.Content, {
                                                tagName: 'p',
                                                value: attributes.introduction,
												style: back_text_style()
                                            }
                                        ),
                                    ),
                                ) : '',
                            ) : '',
                            el('div', {
                                    className: 'cwp-main-wrapper cwp-main-wrapper-single cwp-' + attributes.columns + '-column ' + attributes.positionClass
                                },
                                items.map(function(item, index) {
									var block_back_style = function() {
										var s = {};
										if(item.color !== '' && item.color !== undefined) {
											s = {
												background: item.color
											};
										}
                                        return s;
                                    };
                                    var block_text_style = function() {
										var s = {};
										if(item.textcolor !== '' && item.textcolor !== undefined) {
											s = {
												color: item.textcolor
											};
										}
                                        return s;
                                    };
									var block_border_and_text_style = function() {
										var s = {};
										if(item.textcolor !== '' && item.textcolor !== undefined) {
											s = {
												color: item.textcolor,
												borderColor: item.textcolor
											};
										}
										return s;
									};
									var box_back_style = function() {
										var s = {};
										if(item.boxbgcolor !== '' && item.boxbgcolor !== undefined) {
											s = {
												background: item.boxbgcolor
											};
										}
                                        return s;
                                    };
									var box_text_style = function() {
										var s = {};
										if(item.boxcolor !== '' && item.boxcolor !== undefined) {
											s = {
												color: item.boxcolor
											};
										}
										return s;
									};
                                    return el(
                                        Fragment, {
                                            key: index
                                        },
                                        el('div', {
                                                className: 'cwp-inner-wrap'
                                            },
                                            el('div', {
                                                    className: 'cwp-content-wrap',
													style: box_back_style()
                                                },
                                                item.date !== '' && item.date !== undefined ? el('div', {
                                                        className: 'countdown-timer',
                                                        "data-time": item.date
                                                    },
                                                    el('div', {
                                                            className: "clockdiv"
                                                        },
                                                        /* Print years */
                                                        attributes.showYears === true ? el('div', {
                                                                className: 'main-countdown-years',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-years',
																	style: block_border_and_text_style()
                                                                }
                                                            ),
                                                            el(RichText.Content, {
																tagName: 'div',
																value: attributes.Textyears,
																className: 'smalltext',
																style: block_text_style()
															})
                                                        ) : '',
                                                        /* Print Months */
                                                        attributes.showMonths === true ? el('div', {
                                                                className: 'main-countdown-months',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-months',
																	style: block_border_and_text_style()
                                                                },
                                                            ),
                                                            el(RichText.Content, {
																tagName: 'div',
																value: attributes.Textmonths,
																className: 'smalltext',
																style: block_text_style()
															})
                                                        ) : '',
                                                        /* Print Days */
                                                        attributes.showDays === true ? el('div', {
                                                                className: 'main-countdown-days',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-days',
																	style: block_border_and_text_style()
                                                                },
                                                            ),
                                                            el(RichText.Content, {
																tagName: 'div',
																value: attributes.Textdays,
																className: 'smalltext',
																style: block_text_style()
															})
                                                        ) : '',
                                                        /* Print Hours */
                                                        attributes.showHours === true ? el('div', {
                                                                className: 'main-countdown-hours',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-hours',
																	style: block_border_and_text_style()
                                                                },
                                                            ),
                                                            el(RichText.Content, {
																tagName: 'div',
																value: attributes.Texthours,
																className: 'smalltext',
																style: block_text_style()
															})
                                                        ) : '',
                                                        /* Print Minutes */
                                                        attributes.showMinutes === true ? el('div', {
                                                                className: 'main-countdown-minutes',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-minutes',
																	style: block_border_and_text_style()
                                                                },
                                                            ),
                                                           el(RichText.Content, {
																tagName: 'div',
																value: attributes.Textminutes,
																className: 'smalltext',
																style: block_text_style()
															})
                                                        ) : '',
                                                        /* Print seconds */
                                                        attributes.showSeconds === true ? el('div', {
                                                                className: 'main-countdown-seconds',
																style: Object.assign(block_back_style(), box_style())
                                                            },
                                                            el('div', {
                                                                    className: 'countdown-seconds',
																	style: block_border_and_text_style()
                                                                },
                                                            ),
                                                            el(RichText.Content, {
																tagName: 'div',
																value: attributes.Textseconds,
																className: 'smalltext',
																style: block_text_style()
															})
                                                        ) : ''
                                                    ),
                                                    el('div', {
                                                            className: "clockdiv-msg"
                                                        }
                                                    ),
													item.text !== '' && item.text !== undefined ? el(
														RichText.Content, {
															tagName: 'p',
															value: item.text,
															style: box_text_style()
														}
													) : ''
												) : ''
                                            )
                                        )
                                    );
                                })
                            )
                        )
                    )
                )
            ];
        },
        save: function(props) {
            var attributes = props.attributes;
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}
			
            var items = attributes.link;
            var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var box_style = function() {
				var s = {};
				if(attributes.boxradiusfix === true && attributes.boxradius >= 0)
				{
					s.borderRadius = attributes.boxradius;
				}
				else if(attributes.boxradius > 0)
				{
					s.borderRadius = attributes.boxradius;
				}
				if(attributes.boxpaddingfix === true && attributes.boxpadding >= 0)
				{
					s.padding = attributes.boxpadding;
				}
				else if(attributes.boxpadding > 0)
				{
					s.padding = attributes.boxpadding;
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};

            return el('div', {
					id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                    className: 'cwp-common-main-wrap ' + attributes.container + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
					style: back_style()
                },
                el('div', {
						className: 'cwp-common-main-wrap-inner',
						style: box_padding(),
                        "data-scroll-class": attributes.animationStyle,
                        "data-scroll-delay": attributes.animationDelay,
                        "data-scroll-threshold": attributes.threshold
                    },
                    attributes.introsection === 'enabled' ? el('div', {
                            className: 'cwp-main-intro',
							style: attributes.paddingAfterIntro >= 0 ? {
								paddingBottom: attributes.paddingAfterIntro
							} : {}
                        },
                        (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
								className: 'cwp-intro-title'
							},
							el('h3', {
									style: back_text_style()
								},
								(attributes.introtitle !== '' && attributes.introtitle !== undefined) ? el(
									RichText.Content, {
										tagName: '',
										value: attributes.introtitle
									}
								) : '',
								(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el(
									RichText.Content, {
										tagName: 'span',
										value: attributes.introsubtitle
									}
								) : '',
							),
						) : '',
                        (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                                className: 'cwp-intro-introduction'
                            },
                            el('div', {
                                    className: 'cwp-intro-input'
                                },
                                el(
                                    RichText.Content, {
                                        tagName: 'p',
                                        value: attributes.introduction,
										style: back_text_style()
                                    }
                                ),
                            ),
                        ) : '',
                    ) : '',
                    el('div', {
                            className: 'cwp-main-wrapper cwp-main-wrapper-single cwp-' + attributes.columns + '-column ' + attributes.positionClass
                        },
                        items.map(function(item, index) {
							var block_back_style = function() {
								var s = {};
								if(item.color !== '' && item.color !== undefined) {
									s = {
										background: item.color
									};
								}
								return s;
							};
							var block_text_style = function() {
								var s = {};
								if(item.textcolor !== '' && item.textcolor !== undefined) {
									s = {
										color: item.textcolor
									};
								}
								return s;
							};
							var block_border_and_text_style = function() {
								var s = {};
								if(item.textcolor !== '' && item.textcolor !== undefined) {
									s = {
										color: item.textcolor,
										borderColor: item.textcolor
									};
								}
								return s;
							};
							var box_back_style = function() {
								var s = {};
								if(item.boxbgcolor !== '' && item.boxbgcolor !== undefined) {
									s = {
										background: item.boxbgcolor
									};
								}
								return s;
							};
							var box_text_style = function() {
								var s = {};
								if(item.boxcolor !== '' && item.boxcolor !== undefined) {
									s = {
										color: item.boxcolor
									};
								}
								return s;
							};
                            return el(
                                Fragment, {
                                    key: index
                                },
                                el('div', {
                                        className: 'cwp-inner-wrap'
                                    },
                                    el('div', {
                                            className: 'cwp-content-wrap',
											style: box_back_style()
                                        },
                                        item.date !== '' && item.date !== undefined ? el('div', {
                                                className: 'countdown-timer',
                                                "data-time": item.date
                                            },
                                            el('div', {
													className: "clockdiv"
												},
												/* Print years */
												attributes.showYears === true ? el('div', {
														className: 'main-countdown-years',
														style: Object.assign(block_back_style(), box_style())
													},
													el('div', {
															className: 'countdown-years',
															style: block_border_and_text_style()
														}
													),
													el(RichText.Content, {
														tagName: 'div',
														value: attributes.Textyears,
														className: 'smalltext',
														style: block_text_style()
													})
												) : '',
												/* Print Months */
												attributes.showMonths === true ? el('div', {
														className: 'main-countdown-months',
														style: Object.assign(block_back_style(), box_style())
													},
													el('div', {
															className: 'countdown-months',
															style: block_border_and_text_style()
														},
													),
													el(RichText.Content, {
														tagName: 'div',
														value: attributes.Textmonths,
														className: 'smalltext',
														style: block_text_style()
													})
												) : '',
												/* Print Days */
												attributes.showDays === true ? el('div', {
														className: 'main-countdown-days',
														style: Object.assign(block_back_style(), box_style())
													},
													el('div', {
															className: 'countdown-days',
															style: block_border_and_text_style()
														},
													),
													el(RichText.Content, {
														tagName: 'div',
														value: attributes.Textdays,
														className: 'smalltext',
														style: block_text_style()
													})
												) : '',
												/* Print Hours */
												attributes.showHours === true ? el('div', {
														className: 'main-countdown-hours',
														style: Object.assign(block_back_style(), box_style())
													},
													el('div', {
															className: 'countdown-hours',
															style: block_border_and_text_style()
														},
													),
													el(RichText.Content, {
														tagName: 'div',
														value: attributes.Texthours,
														className: 'smalltext',
														style: block_text_style()
													})
												) : '',
												/* Print Minutes */
												attributes.showMinutes === true ? el('div', {
														className: 'main-countdown-minutes',
														style: Object.assign(block_back_style(), box_style())
													},
													el('div', {
															className: 'countdown-minutes',
															style: block_border_and_text_style()
														},
													),
												   el(RichText.Content, {
														tagName: 'div',
														value: attributes.Textminutes,
														className: 'smalltext',
														style: block_text_style()
													})
												) : '',
												/* Print seconds */
												attributes.showSeconds === true ? el('div', {
														className: 'main-countdown-seconds',
														style: Object.assign(block_back_style(), box_style())
													},
													el('div', {
															className: 'countdown-seconds',
															style: block_border_and_text_style()
														},
													),
													el(RichText.Content, {
														tagName: 'div',
														value: attributes.Textseconds,
														className: 'smalltext',
														style: block_text_style()
													})
												) : ''
											),
                                            el('div', {
													className: "clockdiv-msg"
												}
											),
											item.text !== '' && item.text !== undefined ? el(
												RichText.Content, {
													tagName: 'p',
													value: item.text,
													style: box_text_style()
												}
											) : ''
                                        ) : ''
                                    )
                                )
                            );
                        })
                    )
                )
            );
        },
		example: {
			attributes:{
				blockID: '',
				columns: 1,
				container: 'cwp-full-width-wide-container',
				positionClass: 'cwp-all-center',
				backgroundType: 'color',
				backgroundTextcolor: '',
				solidColor: '',
				gradient: '',
				backgroundMediaID: -1,
				backgroundMediaURL: '',
				animationStyle: '',
				animationDelay: 10,
				threshold: 40,
				paddingBeforeIntro: 50,
				paddingAfterIntro: 50,
				paddingAfterItems: 50,
				introsection: 'empty',
				introtitle: '',
				introsubtitle: '',
				introduction: '',
				boxradius: 0,
				boxradiusfix: false,
				boxpadding: 0,
				boxpaddingfix: false,
				Textyears: 'Years',
				Textmonths: 'Months',
				Textdays: 'Days',
				Texthours: 'Hours',
				Textminutes: 'Minutes',
				Textseconds: 'Seconds',
				showYears: false,
				showMonths: false,
				showDays: true,
				showHours: true,
				showMinutes: true,
				showSeconds: true,
				link:[{
					date: "2020-12-12",
					text: "",
					color: "",
					textcolor: "",
					boxcolor: "",
					boxbgcolor: "#ffffff"
				}]
			}
		}
    });
})(
    window.wp
);