(function(wp) {
    var el = wp.element.createElement;
    var InspectorControls = wp.blockEditor.InspectorControls;
    var RichText = wp.blockEditor.RichText;
    var URLText = wp.blockEditor.URLInput;
    var Fragment = wp.element.Fragment;
    var MediaUpload = wp.blockEditor.MediaUpload;
    var TextControl = wp.components.TextControl;
    var RangeControl = wp.components.RangeControl;
    var SelectControl = wp.components.SelectControl;
    var ButtonGroup = wp.components.ButtonGroup;
    var Button = wp.components.Button;
    var ColorPalette = wp.components.ColorPalette;
    var __ = wp.i18n.__;

    var _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };

    function _LinkMove(e, t, n) {
        var r = e.slice(0);
        if (n >= r.length) {
            for (var o = n - r.length; 1 + o--;) {
                r.push(void 0);
            }
        }
        return r.splice(n, 0, r.splice(t, 1)[0]), r;
    }

    function _populateFeatures(features, columns) {
        newFeatures = features.map(function(feature, featureIndex) {
            var newColumns = feature.column;
            if (feature.column.length !== columns) {
                newColumns = [];
                for (var i = 0; i < columns; i++) {
                    if (i < feature.column.length) {
                        newColumns.push(feature.column[i]);
                    } else {
                        newColumns.push({
                            icon: 'fa-500px',
                            text: ''
                        });
                    }
                }
            }

            return {
                title: feature.title ? feature.title : '',
                subtitle: feature.subtitle ? feature.subtitle : '',
                column: newColumns
            };
        });

        return newFeatures;
    }

    wp.blocks.registerBlockType('cwp/pricelist', {
        title: __('Price List', 'cosmic-blocks'),
		keywords: [
			'price box',
			__('pricelist', 'cosmic-blocks')
		],
        icon: {
			background: "#16A3FF",
			foreground: "#FFFFFF",
			src: "list-view"
		},
        category: 'cwp-blocks',
        attributes: {
			blockID: {
				type: 'string',
				default: ''
			},
            columns: {
                type: "number",
                default: 3
            },
            container: {
                type: "string",
                default: 'cwp-full-width-wide-container'
            },
            backgroundType: {
                type: "string",
                default: 'color'
            },
            backgroundTextColor: {
                type: "string",
                default: ''
            },
            solidColor: {
                type: "string",
                default: ''
            },
            gradient: {
                type: "string"
            },
            backgroundMediaID: {
                type: "number"
            },
            backgroundMediaURL: {
                type: "string"
            },
            animationStyle: {
                type: "string"
            },
            animationDelay: {
                type: "number",
                default: 10
            },
            threshold: {
                type: "number",
                default: 40
            },
            paddingBeforeIntro: {
                type: 'number',
                default: 50
            },
            paddingAfterIntro: {
                type: 'number',
                default: 50
            },
            paddingAfterItems: {
                type: 'number',
                default: 50
            },
			introsection: {
                type: 'string',
                default: 'empty'
            },
            introtitle: {
                type: "string",
                default: ''
            },
            introsubtitle: {
                type: "string",
                default: ''
            },
            introduction: {
                type: "string",
                default: ''
            },
            header: {
                type: 'array',
                default: []
            },
            featureCount: {
                type: 'number',
                default: 0
            },
            feature: {
                type: 'array',
                default: []
            },
            priceTitle: {
                type: "string",
                default: ''
            },
            priceSubtitle: {
                type: "string",
                default: ''
            },
            price: {
                type: 'array',
                default: []
            },
            addonTitle: {
                type: "string",
                default: ''
            },
            addonSubtitle: {
                type: "string",
                default: ''
            },
            addon: {
                type: 'array',
                default: []
            },
            actionTitle: {
                type: "string",
                default: ''
            },
            actionSubtitle: {
                type: "string",
                default: ''
            },
            action: {
                type: 'array',
                default: []
            },
            extra: {
                type: "string",
                default: ''
            }
        },
        getEditWrapperProps({
            container
        }) {
            if ('cwp-full-width-wide-container' === container || 'cwp-full-width-small-container' === container || 'cwp-same-width-full-container' === container) {
                return {
                    'data-align': 'full'
                };
            } else if ('cwp-same-width-wide-container' === container) {
                return {
                    'data-align': 'wide'
                };
            }
        },
        edit: function(props) {
            var attributes = props.attributes;

            // override default params for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{
				attributes.paddingBeforeIntro = -1;
				attributes.paddingAfterIntro = -1;
				attributes.paddingAfterItems = -1;
				attributes.boxradius = -1;
				attributes.boxradiusfix = true;
				attributes.boxpadding = -1;
				attributes.boxpaddingfix = true;
				attributes.container = 'cwp-full-width-small-container';
			}
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}
			
            var headers = attributes.header;
            if (attributes.header.length !== attributes.columns) {
                headers = [];
                for (var i = 0; i < attributes.columns; i++) {
                    if (i < attributes.header.length) {
                        headers.push(attributes.header[i]);
                    } else {
                        headers.push({
                            title: '',
                            subtitle: ''
                        });
                    }
                }
                props.setAttributes({
                    header: headers
                });
            }

            var cwpUpdateHeader = function(value, headerIndex) {
                var attributes = props.attributes;
                var setAttributes = props.setAttributes;
                var headers = attributes.header;

                var newItems = headers.map(function(item, thisIndex) {
                    if (headerIndex === thisIndex) {
                        item = _extends({}, item, value);
                    }
                    return item;
                });

                setAttributes({
                    header: newItems
                });
            };

            // show feature columns by column count
            var features = attributes.feature;
            if ((features.length !== attributes.featureCount) || (attributes.header.length !== attributes.columns)) {
                features = _populateFeatures(features, attributes.columns);
                props.setAttributes({
                    featureCount: features.length,
                    feature: features
                });
            }

            var cwpUpdateFeature = function(value, featureIndex) {
                var attributes = props.attributes;
                var setAttributes = props.setAttributes;
                var features = attributes.feature;

                var newItems = features.map(function(item, thisIndex) {
                    if (featureIndex === thisIndex) {
                        item = _extends({}, item, value);
                    }
                    return item;
                });

                setAttributes({
                    feature: newItems
                });
            };

            var cwpUpdateFeatureColumn = function(value, featureIndex, columnIndex) {

                var attributes = props.attributes;
                var setAttributes = props.setAttributes;
                var features = attributes.feature;

                var newItems = features.map(function(feature, thisFeatureIndex) {

                    if (featureIndex === thisFeatureIndex) {
                        var newColumn = feature.column.map(function(item, thisColumnIndex) {
                            if (columnIndex === thisColumnIndex) {
                                item = _extends({}, item, value);
                            }

                            return item;
                        });

                        feature.column = newColumn;
                    }

                    return feature;
                });

                setAttributes({
                    feature: newItems
                });
            };

            // show prices by column count
            var prices = attributes.price;
            if (attributes.price.length !== attributes.columns) {
                prices = [];
                for (var i = 0; i < attributes.columns; i++) {
                    if (i < attributes.price.length) {
                        prices.push(attributes.price[i]);
                    } else {
                        prices.push({
                            price: '',
                            extra: ''
                        });
                    }
                }
                props.setAttributes({
                    price: prices
                });
            }

            var cwpUpdatePrice = function(value, priceIndex) {
                var attributes = props.attributes;
                var setAttributes = props.setAttributes;
                var prices = attributes.price;

                var newItems = prices.map(function(item, thisIndex) {
                    if (priceIndex === thisIndex) {
                        item = _extends({}, item, value);
                    }
                    return item;
                });

                setAttributes({
                    price: newItems
                });
            };

            // show addons by column count
            var addons = attributes.addon;
            if (attributes.addon.length !== attributes.columns) {
                addons = [];
                for (var i = 0; i < attributes.columns; i++) {
                    if (i < attributes.addon.length) {
                        addons.push(attributes.addon[i]);
                    } else {
                        addons.push({
                            price: '',
                            extra: ''
                        });
                    }
                }
                props.setAttributes({
                    addon: addons
                });
            }

            var cwpUpdateAddon = function(value, addonIndex) {
                var attributes = props.attributes;
                var setAttributes = props.setAttributes;
                var addons = attributes.addon;

                var newItems = addons.map(function(item, thisIndex) {
                    if (addonIndex === thisIndex) {
                        item = _extends({}, item, value);
                    }
                    return item;
                });

                setAttributes({
                    addon: newItems
                });
            };

            // show actions by column count
            var actions = attributes.action;
            if (attributes.action.length !== attributes.columns) {
                actions = [];
                for (var i = 0; i < attributes.columns; i++) {
                    if (i < attributes.action.length) {
                        actions.push(attributes.action[i]);
                    } else {
                        actions.push({
                            primaryStyle: "cwp-button cwp-button-primary",
                            primaryTarget: "_self",
                            primaryReadmoreText: __('Buy now', 'cosmic-blocks'),
                            primaryReadmoreURL: "",
                            secondaryStyle: "cwp-button cwp-button-secondary",
                            secondaryTarget: "_self",
                            secondaryReadmoreText: __('More infos', 'cosmic-blocks'),
                            secondaryReadmoreURL: "",
                        });
                    }
                }
                props.setAttributes({
                    action: actions
                });
            }

            var cwpUpdateAction = function(value, actionIndex) {
                var attributes = props.attributes;
                var setAttributes = props.setAttributes;
                var actions = attributes.action;

                var newItems = actions.map(function(item, thisIndex) {
                    if (actionIndex === thisIndex) {
                        item = _extends({}, item, value);
                    }
                    return item;
                });

                setAttributes({
                    action: newItems
                });
            };

            var solidColorPreset = el(ColorPalette, {
                value: attributes.solidColor,
                onChange: function(e) {
                    props.setAttributes({
                        solidColor: e
                    });
                },
                colors: [{
                    color: "#ffffff",
                    name: "white"
                }, {
                    color: "#00d1b2",
                    name: "teal"
                }, {
                    color: "#3373dc",
                    name: "royal blue"
                }, {
                    color: "#209cef",
                    name: "sky blue"
                }, {
                    color: "#22d25f",
                    name: "green"
                }]
            });

            var backgroundTextColorPreset = el(ColorPalette, {
                value: attributes.backgroundTextColor,
                onChange: function(e) {
                    props.setAttributes({
                        backgroundTextColor: e
                    });
                },
                colors: [{
                    color: "#ffffff",
                    name: "white"
                }, {
                    color: "#333333",
                    name: "dark"
                }, {
                    color: "#000000",
                    name: "black"
                }, {
                    color: "#209cef",
                    name: "sky blue"
                }, {
                    color: "#22d25f",
                    name: "green"
                }]
            });

            var gradientPreset = el(SelectControl, {
                label: __('Gradients', 'cosmic-blocks'),
                options: gradient_options.map(function(e) {
                    return {
                        value: e.colors,
                        label: e.name
                    };
                }),
                value: attributes.gradient,
                onChange: function(e) {
                    props.setAttributes({
                        gradient: e
                    });
                }
            });

            var features = attributes.feature;

            var headers = attributes.header;
            var headersExists = headers.map(function(header) {
                if (header.title !== '') {
                    return 'yes';
                } else if (header.subtitle !== '') {
                    return 'yes';
                }
                return 'no';
            });

            var prices = attributes.price;
            var pricesExists = prices.map(function(price) {
                if (price.price !== '') {
                    return 'yes';
                } else if (price.extra !== '') {
                    return 'yes';
                }
                return 'no';
            });

            var addons = attributes.addon;
            var addonsExists = addons.map(function(addon) {
                if (addon.price !== '') {
                    return 'yes';
                } else if (addon.extra !== '') {
                    return 'yes';
                }
                return 'no';
            });

            var actions = attributes.action;
            var actionsExists = actions.map(function(action) {
                if (action.primaryReadmoreURL !== '' && action.primaryReadmoreURL.length > 0 && action.primaryReadmoreText !== '') {
                    return 'yes';
                }
                if (action.secondaryReadmoreURL !== '' && action.secondaryReadmoreURL.length > 0 && action.secondaryReadmoreText !== '') {
                    return 'yes';
                }
                return 'no';
            });

            var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};

            return [
                el(
                    Fragment,
                    null,
                    el(InspectorControls, {
                            key: 'inspector'
                        }, // Display the block options in the inspector panel.
						el(wp.components.PanelBody, {
								title: __('Intro', 'cosmic-blocks'),
								className: 'cwp-inspector-intro',
								initialOpen: false
							},
							el(SelectControl, {
								label: __('Enable/disable', 'cosmic-blocks'),
								value: attributes.introsection,
								options: [{
										label: __('Disabled', 'cosmic-blocks'),
										value: 'disabled'
									},
									{
										label: __('Enabled', 'cosmic-blocks'),
										value: 'enabled'
									}
								],
								onChange: function onChange(value) {
									props.setAttributes({
										introsection: value
									});
								}
							}),
							attributes.introsection === 'enabled' ? el('p', {}, __('Intro text color', 'cosmic-blocks')) : '',
							attributes.introsection === 'enabled' ? backgroundTextColorPreset : '',
							attributes.introsection === 'enabled' ? el(RangeControl, {
								label: __('Padding after intro text', 'cosmic-blocks'),
								value: attributes.paddingAfterIntro,
								allowReset: false,
								initialPosition: 50,
								onChange: function(e) {
									return props.setAttributes({
										paddingAfterIntro: e
									});
								},
								min: -1,
								max: 200
							}) : '',
						),
                        el(wp.components.PanelBody, {
                                title: __('Layout', 'cosmic-blocks'),
                                className: 'cwp-inspector-layout',
                                initialOpen: false
							},
                            el(SelectControl, {
                                label: __('Container width', 'cosmic-blocks'),
                                value: attributes.container,
                                options: container_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    props.setAttributes({
                                        container: e
                                    });
                                }
                            }),
                            el(RangeControl, {
                                label: __('Padding top', 'cosmic-blocks'),
                                value: attributes.paddingBeforeIntro,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingBeforeIntro: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el(RangeControl, {
                                label: __('Padding bottom', 'cosmic-blocks'),
                                value: attributes.paddingAfterItems,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingAfterItems: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el('p', {
                                className: 'cwp-custom-label'
                            }, __('Background', 'cosmic-blocks')),
                            el(ButtonGroup, {},
                                backgroundType.map(function(e) {
                                    return el(Button, {
                                        key: e.label,
                                        isLarge: !0,
                                        isPrimary: attributes.backgroundType === e.value,
                                        "aria-pressed": attributes.backgroundType === e.value,
                                        onClick: function() {
                                            return props.setAttributes({
                                                backgroundType: e.value
                                            });
                                        }
                                    }, e.label);
                                })
                            ),
                            "color" === attributes.backgroundType && solidColorPreset,
                            "gradient" === attributes.backgroundType && gradientPreset,
                            "image" === attributes.backgroundType && el(
                                MediaUpload, {
                                    key: "mediaupload",
                                    onSelect: function(media) {
                                        return props.setAttributes({
                                            backgroundMediaURL: media.url,
                                            backgroundMediaID: media.id
                                        });
                                    },
                                    type: "image",
                                    value: attributes.backgroundMediaID,
                                    render: function(e) {
                                        var r = e.open;
                                        return el(Fragment, null, el(Button, {
                                            className: "button-link cwp-custom-button",
                                            onClick: r
                                        }, attributes.backgroundMediaID ? el("img", {
                                            src: attributes.backgroundMediaURL
                                        }) : __('Set background image', 'cosmic-blocks')));
                                    }
                                }
                            ),
                            "image" === attributes.backgroundType && attributes.backgroundMediaID && el(Fragment, null, el("p", {
                                className: "cwp-custom-edit-image"
                            }, __('Click the image to edit or update', 'cosmic-blocks')), el(Button, {
                                className: "button-link",
                                style: {
                                    marginBottom: "20px"
                                },
                                onClick: function() {
                                    return props.setAttributes({
                                        backgroundMediaURL: void 0,
                                        backgroundMediaID: void 0
                                    });
                                }
                            }, __('Remove background image', 'cosmic-blocks'))),
                            el(TextControl, {
                                label: __('Block ID', 'cosmic-blocks'),
                                value: attributes.blockID,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        blockID: e
                                    });
                                }
                            }),
						),
						el(wp.components.PanelBody, {
								title: __('Items', 'cosmic-blocks'),
								className: 'cwp-inspector-items',
								initialOpen: true
							},
							el('span', {
									style: {
										display: 'block',
										padding: '0.5rem',
										marginBottom: '1rem',
										border: '2px red solid'
									}
								}, __('Remove cols carefully! When you remove a col, all content of this col is removed too. If you have done this by accident, you can recover the content by reloading the page without saving or you can recover the content from the page revisons.', 'cosmic-blocks')
							),
							el(RangeControl, {
								label: __('Items per row', 'cosmic-blocks'),
								value: attributes.columns,
								onChange: function(e) {
									return props.setAttributes({
										columns: e
									});
								},
								min: 1,
								max: 5
							})
						),
                        el(wp.components.PanelBody, {
                                title: __('Animation', 'cosmic-blocks'),
                                className: 'cwp-inspector-animation',
                                initialOpen: false
                            },
                            el(SelectControl, {
                                label: __('Animation', 'cosmic-blocks'),
                                value: attributes.animationStyle,
                                options: animation_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationStyle: e
                                    });
                                }
                            }),
                            el(TextControl, {
                                label: __('Animation Delay', 'cosmic-blocks'),
                                value: attributes.animationDelay,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationDelay: e
                                    });
                                },
                                help: __('Enter in milliseconds', 'cosmic-blocks')
                            }),
                            el(RangeControl, {
                                beforeIcon: 'arrow-left-alt2',
                                afterIcon: 'arrow-right-alt2',
                                label: __('Threshold', 'cosmic-blocks'),
                                value: attributes.threshold,
                                allowReset: false,
                                initialPosition: 40,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        threshold: e
                                    });
                                },
                                min: 0,
                                max: 100
                            }),
                        )
                    ),
                    el('div', {
							id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-backend-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                            style: back_style()
                        },
                        el('div', {
                                className: 'cwp-common-main-wrap-inner' + (attributes.animationStyle !== '' && attributes.animationStyle !== undefined ? ' animated ' + attributes.animationStyle : ''),
                                style: box_padding()
                            },
                            attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
                                    style: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'h3',
                                            placeholder: __('Title', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introtitle,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
											allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-subtitle'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Subtitle', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introsubtitle,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
											allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introsubtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Introduction', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introduction,
                                            style: back_text_style(),
                                            isSelected: attributes.isSelected,
											allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introduction: e
                                                });
                                            }
                                        }),
                                    ),
                                )
                            ) : '',
                            el('div', {
                                    className: 'cwp-pricelist-header cwp-main-wrapper-outer'
                                },
                                el('div', {
                                        className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                                    },
                                    el('div', {
                                            className: 'cwp-inner-wrap'
                                        },
                                        el('div', {
                                            className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                        }, )
                                    ),
                                    headers.map(function(header, index) {
                                        return el(
                                            Fragment, {
                                                key: index
                                            },
                                            el('div', {
                                                    className: 'cwp-inner-wrap'
                                                },
                                                el('div', {
                                                        className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                                    },
                                                    el(RichText, {
                                                        tagName: 'h3',
                                                        placeholder: __('Offer title', 'cosmic-blocks'),
                                                        value: header.title,
														isSelected: attributes.isSelected,
														allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                        onChange: function onChange(value) {
                                                            return cwpUpdateHeader({
                                                                title: value
                                                            }, index);
                                                        }
                                                    }),
                                                    el(RichText, {
                                                        tagName: 'p',
                                                        placeholder: __('Subtitle', 'cosmic-blocks'),
                                                        value: header.subtitle,
														isSelected: attributes.isSelected,
														allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                        onChange: function onChange(value) {
                                                            return cwpUpdateHeader({
                                                                subtitle: value
                                                            }, index);
                                                        }
                                                    })
                                                ),
                                            )
                                        );
                                    })
                                )
                            ),
							el('div', {
									className: 'cwp-main-wrapper-repeat'
								},
								features.map(function(feature, featureIndex) {
									return el(
										Fragment, {
											key: featureIndex
										},
										el('div', {
												className: 'cwp-pricelist-body cwp-main-wrapper-outer'
											},
											el('div', {
													className: 'cwp-meta-options'
												},
												el('div', {
														className: 'cwp-drag-item cwp-drag-item-wrapper'
													}, el('span', {
															className: "dashicons dashicons-move"
														},
														el('div', {
																className: 'cwp-drag-item-container'
															},
															el('div', {
																	className: 'cwp-drag-item-container-inner'
																},
																el('div', {
																	className: 'cwp-drag-item-upanddown'
																	},
																		el('div', {
																		className: 'cwp-drag-item-move cwp-drag-item-up',
																		onClick: function() {
																			var old_index = featureIndex,
																				next_index = featureIndex - 1,
																				new_items = _LinkMove(features, old_index, next_index);
																			return props.setAttributes({
																				feature: new_items
																			});
																		}
																	}, el('div', null, el('span', {
																		className: "dashicons dashicons-arrow-up-alt2"
																	}))),
																	el('div', {
																		className: 'cwp-drag-item-move cwp-drag-item-down',
																		onClick: function() {
																			var old_index = featureIndex,
																				next_index = featureIndex + 1,
																				new_items = _LinkMove(features, old_index, next_index);
																			return props.setAttributes({
																				feature: new_items
																			});
																		}
																	}, el('div', null, el('span', {
																		className: "dashicons dashicons-arrow-down-alt2"
																	}))),
																)
															)
														)
													)
												),
												el('div', {
													className: 'cwp-remove',
													title: __('Remove', 'cosmic-blocks'),
													onClick: function removeClick() {
														if (confirm(__('Are you sure?', 'cosmic-blocks'))) {
															return props.setAttributes({
																feature: features.filter(function(cItem, cIndex) {
																	return cIndex !== featureIndex;
																})
															});
														}
													}
												}, el('div', null, el('span', {
													className: "dashicons dashicons-trash"
												}))),
											),
											el('div', {
													className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
												},
												el('div', {
														className: 'cwp-inner-wrap'
													},
													el('div', {
															className: 'cwp-content-wrap' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
														},
														el(RichText, {
															tagName: 'h3',
															placeholder: __('Feature', 'cosmic-blocks'),
															value: feature.title,
															isSelected: attributes.isSelected,
															allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
															onChange: function onChange(value) {
																return cwpUpdateFeature({
																	title: value
																}, featureIndex);
															}
														}),
														el(RichText, {
															tagName: 'p',
															placeholder: __('Subtitle', 'cosmic-blocks'),
															value: feature.subtitle,
															isSelected: attributes.isSelected,
															allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
															onChange: function onChange(value) {
																return cwpUpdateFeature({
																	subtitle: value
																}, featureIndex);
															}
														})
													),
												),
												feature.column.map(function(column, columnIndex) {
													return el(
														Fragment, {
															key: columnIndex
														},
														el('div', {
																className: 'cwp-inner-wrap'
															},
															el('div', {
																	className: 'cwp-content-wrap' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
																},
																el('div', {
																		className: 'cwp-icon-picker'
																	},
																	el(SelectControl, {
																		value: column.icon,
																		options: icon_options.map(function(e) {
																			return {
																				value: e.value,
																				label: e.label
																			};
																		}),
																		onChange: function onChange(value) {
																			return cwpUpdateFeatureColumn({
																				icon: value
																			}, featureIndex, columnIndex);
																		}
																	}),
																	el(cwpIconPicker, {
																		onChange: function onChange(value) {
																			return cwpUpdateFeatureColumn({
																				icon: value
																			}, featureIndex, columnIndex);
																		}
																	})
																),
																el('div', {
																		className: 'cwp-icon'
																	},
																	el('i', {
																		className: 'fa ' + column.icon
																	}),
																	column.icon && el('div', {
																			className: 'remove-icon',
																			title: __('Remove Icon', 'cosmic-blocks'),
																			onClick: function() {
																				if (confirm('Remove Icon?')) {
																					return cwpUpdateFeatureColumn({
																						icon: void 0
																					}, featureIndex, columnIndex);
																				}
																			}
																		},
																		el('span', {
																			className: "dashicons dashicons-no-alt"
																		})
																	)
																),
																el(RichText, {
																	tagName: 'p',
																	placeholder: __('Text', 'cosmic-blocks'),
																	value: column.text,
																	isSelected: attributes.isSelected,
																	allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
																	onChange: function onChange(value) {
																		return cwpUpdateFeatureColumn({
																			text: value
																		}, featureIndex, columnIndex);
																	}
																})
															)
														)
													);
												})
											)
										)
									);
								})
							),
                            el('div', {
                                    className: "cwp-add-new"
                                },
                                el(
                                    "button", {
                                        className: "button button-large button-primary",
                                        onClick: function NewClick() {
                                            var newFeatures = attributes.feature;
                                            newFeatures.push({
                                                title: '',
                                                column: []
                                            });

                                            newFeatures = _populateFeatures(newFeatures, attributes.columns);
                                            return props.setAttributes({
                                                featureCount: newFeatures.length,
                                                feature: newFeatures
                                            });
                                        }
                                    },
                                    __('Add', 'cosmic-blocks')
                                )
                            ),
                            el('div', {
                                    className: 'cwp-pricelist-price cwp-main-wrapper-outer'
                                },
                                el('div', {
                                        className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                                    },
                                    el('div', {
                                            className: 'cwp-inner-wrap'
                                        },
                                        el('div', {
                                                className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                            },
                                            el(RichText, {
                                                tagName: 'h3',
                                                placeholder: __('Title', 'cosmic-blocks'),
                                                value: attributes.priceTitle,
												isSelected: attributes.isSelected,
												allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                onChange: function onChange(value) {
                                                    return props.setAttributes({
                                                        priceTitle: value
                                                    });
                                                }
                                            }),
                                            el(RichText, {
                                                tagName: 'p',
                                                placeholder: __('Subtitle', 'cosmic-blocks'),
                                                value: attributes.priceSubtitle,
												isSelected: attributes.isSelected,
												allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                onChange: function onChange(value) {
                                                    return props.setAttributes({
                                                        priceSubtitle: value
                                                    });
                                                }
                                            }),
                                        ),
                                    ),
                                    prices.map(function(price, index) {
                                        return el(
                                            Fragment, {
                                                key: index
                                            },
                                            el('div', {
                                                    className: 'cwp-inner-wrap'
                                                },
                                                el('div', {
                                                        className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                                    },
                                                    el(RichText, {
                                                        tagName: 'h3',
                                                        placeholder: __('$50', 'cosmic-blocks'),
                                                        value: price.price,
														isSelected: attributes.isSelected,
														allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                        onChange: function onChange(value) {
                                                            return cwpUpdatePrice({
                                                                price: value
                                                            }, index);
                                                        }
                                                    }),
                                                    el(RichText, {
                                                        tagName: 'p',
                                                        placeholder: __('per Month', 'cosmic-blocks'),
                                                        value: price.extra,
														isSelected: attributes.isSelected,
														allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                        onChange: function onChange(value) {
                                                            return cwpUpdatePrice({
                                                                extra: value
                                                            }, index);
                                                        }
                                                    }),
                                                ),
                                            )
                                        );
                                    }),
                                )
                            ),
                            el('div', {
                                    className: 'cwp-pricelist-addon cwp-main-wrapper-outer'
                                },
                                el('div', {
                                        className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                                    },
                                    el('div', {
                                            className: 'cwp-inner-wrap'
                                        },
                                        el('div', {
                                                className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                            },
                                            el(RichText, {
                                                tagName: 'h3',
                                                placeholder: __('Title', 'cosmic-blocks'),
                                                value: attributes.addonTitle,
												isSelected: attributes.isSelected,
												allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                onChange: function onChange(value) {
                                                    return props.setAttributes({
                                                        addonTitle: value
                                                    });
                                                }
                                            }),
                                            el(RichText, {
                                                tagName: 'p',
                                                placeholder: __('Subtitle', 'cosmic-blocks'),
                                                value: attributes.addonSubtitle,
												isSelected: attributes.isSelected,
												allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                onChange: function onChange(value) {
                                                    return props.setAttributes({
                                                        addonSubtitle: value
                                                    });
                                                }
                                            }),
                                        ),
                                    ),
                                    addons.map(function(addon, index) {
                                        return el(
                                            Fragment, {
                                                key: index
                                            },
                                            el('div', {
                                                    className: 'cwp-inner-wrap'
                                                },
                                                el('div', {
                                                        className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                                    },
                                                    el(RichText, {
                                                        tagName: 'h3',
                                                        placeholder: __('$250', 'cosmic-blocks'),
                                                        value: addon.price,
														isSelected: attributes.isSelected,
														allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                        onChange: function onChange(value) {
                                                            return cwpUpdateAddon({
                                                                price: value
                                                            }, index);
                                                        }
                                                    }),
                                                    el(RichText, {
                                                        tagName: 'p',
                                                        placeholder: __('Extra fee', 'cosmic-blocks'),
                                                        value: addon.extra,
														isSelected: attributes.isSelected,
														allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                        onChange: function onChange(value) {
                                                            return cwpUpdateAddon({
                                                                extra: value
                                                            }, index);
                                                        }
                                                    }),
                                                ),
                                            )
                                        );
                                    }),
                                )
                            ),
                            el('div', {
                                    className: 'cwp-pricelist-action cwp-main-wrapper-outer'
                                },
                                el('div', {
                                        className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                                    },
                                    el('div', {
                                            className: 'cwp-inner-wrap'
                                        },
                                        el('div', {
                                                className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                            },
                                            el(RichText, {
                                                tagName: 'h3',
                                                placeholder: __('Title', 'cosmic-blocks'),
                                                value: attributes.actionTitle,
												isSelected: attributes.isSelected,
												allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                onChange: function onChange(value) {
                                                    return props.setAttributes({
                                                        actionTitle: value
                                                    });
                                                }
                                            }),
                                            el(RichText, {
                                                tagName: 'p',
                                                placeholder: __('Subtitle', 'cosmic-blocks'),
                                                value: attributes.actionSubtitle,
												isSelected: attributes.isSelected,
												allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                onChange: function onChange(value) {
                                                    return props.setAttributes({
                                                        actionSubtitle: value
                                                    });
                                                }
                                            }),
                                        ),
                                    ),
                                    actions.map(function(action, index) {
                                        return el(
                                            Fragment, {
                                                key: index
                                            },
                                            el('div', {
                                                    className: 'cwp-inner-wrap'
                                                },
                                                el('div', {
                                                        className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                                    },
                                                    el('div', {
                                                            className: 'cwp-button-wrap'
                                                        },
														el(URLText, {
                                                            value: action.primaryReadmoreURL,
                                                            onChange: function onChange(value) {
                                                                return cwpUpdateAction({
                                                                    primaryReadmoreURL: value
                                                                }, index);
                                                            }
                                                        }),
														action.primaryReadmoreURL !== '' && action.primaryReadmoreURL !== undefined ? el(SelectControl, {
															value: action.primaryTarget,
															options: [{
																	label: __('Open link in same window', 'cosmic-blocks'),
																	value: '_self'
																},
																{
																	label: __('Open link in new window', 'cosmic-blocks'),
																	value: '_blank'
																}
															],
															onChange: function onChange(value) {
																return cwpUpdateAction({
																	primaryTarget: value
																}, index);
															}
														}) : '',
														action.primaryReadmoreURL !== '' && action.primaryReadmoreURL !== undefined ?  el(SelectControl, {
															value: action.primaryStyle,
															options: button_options.map(function(e) {
																return {
																	value: e.value,
																	label: e.label
																}
															}),
															onChange: function onChange(value) {
																return cwpUpdateAction({
																	primaryStyle: value
																}, index);
															}
														}) : '',
                                                        action.primaryReadmoreURL !== '' && action.primaryReadmoreURL !== undefined ? el(RichText, {
                                                            tagName: 'div',
															className: action.primaryStyle,
                                                            placeholder: '',
                                                            keepPlaceholderOnFocus: true,
                                                            value: action.primaryReadmoreText,
                                                            multiline: false,
															isSelected: attributes.isSelected,
                                                            allowedFormats: [],
                                                            onChange: function onChange(value) {
                                                                return cwpUpdateAction({
                                                                    primaryReadmoreText: value
                                                                }, index);
                                                            }
                                                        }) : '',
                                                    ),
                                                    el('hr'),
                                                    el('div', {
                                                            className: 'cwp-button-wrap'
                                                        },
														el(URLText, {
                                                            value: action.secondaryReadmoreURL,
                                                            onChange: function onChange(value) {
                                                                return cwpUpdateAction({
                                                                    secondaryReadmoreURL: value
                                                                }, index);
                                                            }
                                                        }),
														action.secondaryReadmoreURL !== '' && action.secondaryReadmoreURL !== undefined ? el(SelectControl, {
															value: action.secondaryTarget,
															options: [{
																	label: __('Open link in same window', 'cosmic-blocks'),
																	value: '_self'
																},
																{
																	label: __('Open link in new window', 'cosmic-blocks'),
																	value: '_blank'
																}
															],
															onChange: function onChange(value) {
																return cwpUpdateAction({
																	secondaryTarget: value
																}, index);
															}
														}) : '',
														action.secondaryReadmoreURL !== '' && action.secondaryReadmoreURL !== undefined ? el(SelectControl, {
															value: action.secondaryStyle,
															options: button_options.map(function(e) {
																return {
																	value: e.value,
																	label: e.label
																};
															}),
															onChange: function onChange(value) {
																return cwpUpdateAction({
																	secondaryStyle: value
																}, index);
															}
														}) : '',
                                                        action.secondaryReadmoreURL !== '' && action.secondaryReadmoreURL !== undefined ? el(RichText, {
                                                            tagName: 'div',
															className: action.secondaryStyle,
                                                            placeholder: '',
                                                            keepPlaceholderOnFocus: true,
                                                            value: action.secondaryReadmoreText,
                                                            multiline: false,
															isSelected: attributes.isSelected,
                                                            allowedFormats: [],
                                                            onChange: function onChange(value) {
                                                                return cwpUpdateAction({
                                                                    secondaryReadmoreText: value
                                                                }, index);
                                                            }
                                                        }) : ''
                                                    )
                                                ),
                                            )
                                        );
                                    }),
                                )
                            ),
                            el('div', {
                                    className: 'cwp-pricelist-extra cwp-main-wrapper-outer'
                                },
                                el('div', {
                                        className: 'cwp-main-wrapper cwp-1-column'
                                    },
                                    el('div', {
                                            className: 'cwp-inner-wrap'
                                        },
                                        el('div', {
                                                className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                            },
                                            el(RichText, {
                                                tagName: 'p',
                                                placeholder: 'Consequatur tempora vel error et amet corporis quidem. Enim incidunt earum accusamus reprehenderit aspernatur quisquam.',
                                                value: attributes.extra,
												isSelected: attributes.isSelected,
												allowedFormats: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                                onChange: function onChange(value) {
                                                    return props.setAttributes({
                                                        extra: value
                                                    });
                                                }
                                            }),
                                        ),
                                    )
                                )
                            )
                        )
                    ),

                    /************* Back Preview **************/

                    el('div', {
							id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-front-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                            style: back_style()
                        },
                        el('div', {
                                className: 'cwp-common-main-wrap ' + attributes.container + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                                style: back_style()
                            },
                            el('div', {
                                    className: 'cwp-common-main-wrap-inner',
                                   style: box_padding(),
                                    "data-scroll-class": attributes.animationStyle,
                                    "data-scroll-delay": attributes.animationDelay,
                                    "data-scroll-threshold": attributes.threshold
                                },
                                attributes.introsection === 'enabled' ? el('div', {
                                        className: 'cwp-main-intro',
                                        style: attributes.paddingAfterIntro >= 0 ? {
											paddingBottom: attributes.paddingAfterIntro
										} : {}
                                    },
                                    (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
                                            className: 'cwp-intro-title'
                                        },
                                        el('h3', {
                                                style: back_text_style()
                                            },
                                            (attributes.introtitle !== '' && attributes.introtitle !== undefined) ? el(
                                                RichText.Content, {
                                                    tagName: '',
                                                    value: attributes.introtitle
                                                }
                                            ) : '',
                                            (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el(
                                                RichText.Content, {
                                                    tagName: 'span',
                                                    value: attributes.introsubtitle
                                                }
                                            ) : '',
                                        ),
                                    ) : '',
                                    (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                                            className: 'cwp-intro-introduction'
                                        },
                                        el('div', {
                                                className: 'cwp-intro-input'
                                            },
                                            el(
                                                RichText.Content, {
                                                    tagName: 'p',
                                                    value: attributes.introduction,
                                                    style: back_text_style()
                                                }
                                            ),
                                        ),
                                    ) : '',
                                ) : '',
                                (headersExists.indexOf('yes') > -1) ? el('div', {
                                        className: 'cwp-pricelist-header cwp-main-wrapper-outer'
                                    },
                                    el('div', {
                                            className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                                        },
                                        el('div', {
                                                className: 'cwp-inner-wrap cwp-inner-wrap-first'
                                            },
                                            el('div', {
                                                className: 'cwp-content-wrap cwp-content-wrap-box'
                                            }, )
                                        ),
                                        headers.map(function(header, index) {
                                            return el(
                                                Fragment, {
                                                    key: index
                                                },
                                                el('div', {
                                                        className: 'cwp-inner-wrap cwp-inner-wrap-equal'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-content-wrap cwp-content-wrap-box'
                                                        },
                                                        header.title !== '' ? el(RichText.Content, {
                                                            tagName: 'h3',
                                                            value: header.title
                                                        }) : '',
                                                        header.subtitle !== '' ? el(RichText.Content, {
                                                            tagName: 'p',
                                                            value: header.subtitle
                                                        }) : ''
                                                    ),
                                                )
                                            );
                                        })
                                    )
                                ) : '',
                                features.map(function(feature, featureIndex) {
                                    return el(
                                        Fragment, {
                                            key: featureIndex
                                        },
                                        el('div', {
                                                className: 'cwp-pricelist-body cwp-main-wrapper-outer'
                                            },
                                            el('div', {
                                                    className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                                                },
                                                el('div', {
                                                        className: 'cwp-inner-wrap cwp-inner-wrap-first'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-content-wrap'
                                                        },
                                                        feature.title !== '' ? el(RichText.Content, {
                                                            tagName: 'h3',
                                                            value: feature.title
                                                        }) : '',
                                                        feature.subtitle !== '' ? el(RichText.Content, {
                                                            tagName: 'p',
                                                            value: feature.subtitle
                                                        }) : ''
                                                    ),
                                                ),
                                                feature.column.map(function(column, columnIndex) {
                                                    return el(
                                                        Fragment, {
                                                            key: columnIndex
                                                        },
                                                        el('div', {
                                                                className: 'cwp-inner-wrap cwp-inner-wrap-equal'
                                                            },
                                                            el('div', {
                                                                    className: 'cwp-content-wrap'
                                                                },
                                                                el('div', {
                                                                        className: 'cwp-icon'
                                                                    },
                                                                    el('i', {
                                                                        className: 'fa ' + column.icon
                                                                    })
                                                                ),
                                                                column.text !== '' ? el(RichText.Content, {
                                                                    tagName: 'p',
                                                                    value: column.text
                                                                }) : ''
                                                            )
                                                        )
                                                    );
                                                })
                                            )
                                        )
                                    );
                                }),
                                attributes.priceTitle !== '' || attributes.priceSubtitle !== '' || (pricesExists.indexOf('yes') > -1) ? el('div', {
                                        className: 'cwp-pricelist-price cwp-main-wrapper-outer'
                                    },
                                    el('div', {
                                            className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                                        },
                                        el('div', {
                                                className: 'cwp-inner-wrap cwp-inner-wrap-first'
                                            },
                                            el('div', {
                                                    className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                                },
                                                attributes.priceTitle !== '' ? el(RichText.Content, {
                                                    tagName: 'h3',
                                                    value: attributes.priceTitle
                                                }) : '',
                                                attributes.priceSubtitle !== '' ? el(RichText.Content, {
                                                    tagName: 'p',
                                                    value: attributes.priceSubtitle
                                                }) : '',
                                            ),
                                        ),
                                        prices.map(function(price, index) {
                                            return el(
                                                Fragment, {
                                                    key: index
                                                },
                                                el('div', {
                                                        className: 'cwp-inner-wrap cwp-inner-wrap-equal'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-content-wrap cwp-content-wrap-box'
                                                        },
                                                        price.price !== '' ? el(RichText.Content, {
                                                            tagName: 'h3',
                                                            value: price.price
                                                        }) : '',
                                                        price.extra !== '' ? el(RichText.Content, {
                                                            tagName: 'p',
                                                            value: price.extra
                                                        }) : ''
                                                    ),
                                                )
                                            );
                                        }),
                                    )
                                ) : '',
                                attributes.addonTitle !== '' || attributes.addonSubtitle !== '' || (addonsExists.indexOf('yes') > -1) ? el('div', {
                                        className: 'cwp-pricelist-addon cwp-main-wrapper-outer'
                                    },
                                    el('div', {
                                            className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                                        },
                                        el('div', {
                                                className: 'cwp-inner-wrap cwp-inner-wrap-first'
                                            },
                                            el('div', {
                                                    className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                                },
                                                attributes.addonTitle !== '' ? el(RichText.Content, {
                                                    tagName: 'h3',
                                                    value: attributes.addonTitle
                                                }) : '',
                                                attributes.addonSubtitle !== '' ? el(RichText.Content, {
                                                    tagName: 'p',
                                                    value: attributes.addonSubtitle
                                                }) : '',
                                            ),
                                        ),
                                        addons.map(function(addon, index) {
                                            return el(
                                                Fragment, {
                                                    key: index
                                                },
                                                el('div', {
                                                        className: 'cwp-inner-wrap cwp-inner-wrap-equal'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-content-wrap cwp-content-wrap-box'
                                                        },
                                                        el(RichText.Content, {
                                                            tagName: 'h3',
                                                            value: addon.price
                                                        }),
                                                        el(RichText.Content, {
                                                            tagName: 'p',
                                                            value: addon.extra
                                                        }),
                                                    ),
                                                )
                                            );
                                        })
                                    )
                                ) : '',
                                attributes.actionTitle !== '' || attributes.actionSubtitle !== '' || (actionsExists.indexOf('yes') > -1) ? el('div', {
                                        className: 'cwp-pricelist-action cwp-main-wrapper-outer'
                                    },
                                    el('div', {
                                            className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                                        },
                                        el('div', {
                                                className: 'cwp-inner-wrap cwp-inner-wrap-first'
                                            },
                                            el('div', {
                                                    className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                                },
                                                attributes.actionTitle !== '' ? el(RichText.Content, {
                                                    tagName: 'h3',
                                                    value: attributes.actionTitle
                                                }) : '',
                                                attributes.actionSubtitle !== '' ? el(RichText.Content, {
                                                    tagName: 'p',
                                                    value: attributes.actionSubtitle
                                                }) : '',
                                            ),
                                        ),
                                        actions.map(function(action, index) {
                                            return el(
                                                Fragment, {
                                                    key: index
                                                },
                                                el('div', {
                                                        className: 'cwp-inner-wrap cwp-inner-wrap-equal'
                                                    },
                                                    el('div', {
                                                            className: 'cwp-content-wrap cwp-content-wrap-box'
                                                        },
                                                        action.primaryReadmoreURL !== '' && action.primaryReadmoreURL.length > 0 && action.primaryReadmoreText !== '' && el('div', {
                                                                className: 'cwp-button-wrap'
                                                            },
                                                            el(RichText.Content, {
																tagName: 'a',
																value: action.primaryReadmoreText,
																className: action.primaryStyle,
																href: action.primaryReadmoreURL,
																target: action.primaryTarget,
																rel: action.primaryTarget ? 'noopener noreferrer' : null
															})
                                                        ),
                                                        action.secondaryReadmoreURL !== '' && action.secondaryReadmoreURL.length > 0 && action.secondaryReadmoreText !== '' && el('div', {
                                                                className: 'cwp-button-wrap'
                                                            },
                                                             el(RichText.Content, {
																tagName: 'a',
																value: action.secondaryReadmoreText,
																className: action.secondaryStyle,
																href: action.secondaryReadmoreURL,
																target: action.secondaryTarget,
																rel: action.secondaryTarget ? 'noopener noreferrer' : null
															})
                                                        )
                                                    )
                                                )
                                            );
                                        })
                                    )
                                ) : '',
                                attributes.extra !== '' ? el('div', {
                                        className: 'cwp-pricelist-extra cwp-main-wrapper-outer'
                                    },
                                    el('div', {
                                            className: 'cwp-main-wrapper cwp-1-column'
                                        },
                                        el('div', {
                                                className: 'cwp-inner-wrap'
                                            },
                                            el('div', {
                                                    className: 'cwp-content-wrap cwp-content-wrap-box'
                                                },
                                                el(RichText.Content, {
                                                    tagName: 'p',
                                                    value: attributes.extra
                                                }),
                                            ),
                                        )
                                    )
                                ) : ''
                            )
                        )
                    ),

                    /************ Front View ***************/

                )
            ];
        },
        save: function(props) {
            var attributes = props.attributes;
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}
			
            var features = attributes.feature;

            var headers = attributes.header;
            var headersExists = headers.map(function(header) {
                if (header.title !== '') {
                    return 'yes';
                } else if (header.subtitle !== '') {
                    return 'yes';
                }
                return 'no';
            });

            var prices = attributes.price;
            var pricesExists = prices.map(function(price) {
                if (price.price !== '') {
                    return 'yes';
                } else if (price.extra !== '') {
                    return 'yes';
                }
                return 'no';
            });

            var addons = attributes.addon;
            var addonsExists = addons.map(function(addon) {
                if (addon.price !== '') {
                    return 'yes';
                } else if (addon.extra !== '') {
                    return 'yes';
                }
                return 'no';
            });

            var actions = attributes.action;
            var actionsExists = actions.map(function(action) {
                if (action.primaryReadmoreURL !== '' && action.primaryReadmoreURL.length > 0 && action.primaryReadmoreText !== '') {
                    return 'yes';
                }
                if (action.secondaryReadmoreURL !== '' && action.secondaryReadmoreURL.length > 0 && action.secondaryReadmoreText !== '') {
                    return 'yes';
                }
                return 'no';
            });

            var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};

            return el('div', {
					id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                    className: 'cwp-common-main-wrap ' + attributes.container + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                    style: back_style()
                },
                el('div', {
                        className: 'cwp-common-main-wrap-inner',
                        style: box_padding(),
                        "data-scroll-class": attributes.animationStyle,
                        "data-scroll-delay": attributes.animationDelay,
                        "data-scroll-threshold": attributes.threshold
                    },
                    attributes.introsection === 'enabled' ? el('div', {
                            className: 'cwp-main-intro',
                            style: attributes.paddingAfterIntro >= 0 ? {
								paddingBottom: attributes.paddingAfterIntro
							} : {}
                        },
                        (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
                                className: 'cwp-intro-title'
                            },
                            el('h3', {
                                    style: back_text_style()
                                },
                                (attributes.introtitle !== '' && attributes.introtitle !== undefined) ? el(
                                    RichText.Content, {
                                        tagName: '',
                                        value: attributes.introtitle
                                    }
                                ) : '',
                                (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el(
                                    RichText.Content, {
                                        tagName: 'span',
                                        value: attributes.introsubtitle
                                    }
                                ) : '',
                            ),
                        ) : '',
                        (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                                className: 'cwp-intro-introduction'
                            },
                            el('div', {
                                    className: 'cwp-intro-input'
                                },
                                el(
                                    RichText.Content, {
                                        tagName: 'p',
                                        value: attributes.introduction,
                                        style: back_text_style()
                                    }
                                ),
                            ),
                        ) : '',
                    ) : '',
					(headersExists.indexOf('yes') > -1) ? el('div', {
                            className: 'cwp-pricelist-header cwp-main-wrapper-outer'
                        },
                        el('div', {
                                className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                            },
                            el('div', {
                                    className: 'cwp-inner-wrap cwp-inner-wrap-first'
                                },
                                el('div', {
                                    className: 'cwp-content-wrap cwp-content-wrap-box'
                                }, )
                            ),
                            headers.map(function(header, index) {
                                return el(
                                    Fragment, {
                                        key: index
                                    },
                                    el('div', {
                                            className: 'cwp-inner-wrap cwp-inner-wrap-equal'
                                        },
                                        el('div', {
                                                className: 'cwp-content-wrap cwp-content-wrap-box'
                                            },
                                            header.title !== '' ? el(RichText.Content, {
                                                tagName: 'h3',
                                                value: header.title
                                            }) : '',
                                            header.subtitle !== '' ? el(RichText.Content, {
                                                tagName: 'p',
                                                value: header.subtitle
                                            }) : ''
                                        ),
                                    )
                                );
                            })
                        )
                    ) : '',
					el('div', {
							className: 'cwp-main-wrapper-repeat'
						},
						features.map(function(feature, featureIndex) {
							return el(
								Fragment, {
									key: featureIndex
								},
								el('div', {
										className: 'cwp-pricelist-body cwp-main-wrapper-outer'
									},
									el('div', {
											className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
										},
										el('div', {
												className: 'cwp-inner-wrap cwp-inner-wrap-first'
											},
											el('div', {
													className: 'cwp-content-wrap'
												},
												feature.title !== '' ? el(RichText.Content, {
													tagName: 'h3',
													value: feature.title
												}) : '',
												feature.subtitle !== '' ? el(RichText.Content, {
													tagName: 'p',
													value: feature.subtitle
												}) : ''
											),
										),
										feature.column.map(function(column, columnIndex) {
											return el(
												Fragment, {
													key: columnIndex
												},
												el('div', {
														className: 'cwp-inner-wrap cwp-inner-wrap-equal'
													},
													el('div', {
															className: 'cwp-content-wrap'
														},
														el('div', {
																className: 'cwp-icon'
															},
															el('i', {
																className: 'fa ' + column.icon
															})
														),
														column.text !== '' ? el(RichText.Content, {
															tagName: 'p',
															value: column.text
														}) : ''
													)
												)
											);
										})
									)
								)
							);
						})
					),
                    attributes.priceTitle !== '' || attributes.priceSubtitle !== '' || (pricesExists.indexOf('yes') > -1) ? el('div', {
                            className: 'cwp-pricelist-price cwp-main-wrapper-outer'
                        },
                        el('div', {
                                className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                            },
                            el('div', {
                                    className: 'cwp-inner-wrap cwp-inner-wrap-first'
                                },
                                el('div', {
                                        className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                    },
                                    attributes.priceTitle !== '' ? el(RichText.Content, {
                                        tagName: 'h3',
                                        value: attributes.priceTitle
                                    }) : '',
                                    attributes.priceSubtitle !== '' ? el(RichText.Content, {
                                        tagName: 'p',
                                        value: attributes.priceSubtitle
                                    }) : '',
                                ),
                            ),
                            prices.map(function(price, index) {
                                return el(
                                    Fragment, {
                                        key: index
                                    },
                                    el('div', {
                                            className: 'cwp-inner-wrap cwp-inner-wrap-equal'
                                        },
                                        el('div', {
                                                className: 'cwp-content-wrap cwp-content-wrap-box'
                                            },
                                            price.price !== '' ? el(RichText.Content, {
                                                tagName: 'h3',
                                                value: price.price
                                            }) : '',
                                            price.extra !== '' ? el(RichText.Content, {
                                                tagName: 'p',
                                                value: price.extra
                                            }) : ''
                                        ),
                                    )
                                );
                            }),
                        )
                    ) : '',
                    attributes.addonTitle !== '' || attributes.addonSubtitle !== '' || (addonsExists.indexOf('yes') > -1) ? el('div', {
                            className: 'cwp-pricelist-addon cwp-main-wrapper-outer'
                        },
                        el('div', {
                                className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                            },
                            el('div', {
                                    className: 'cwp-inner-wrap cwp-inner-wrap-first'
                                },
                                el('div', {
                                        className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                    },
                                    attributes.addonTitle !== '' ? el(RichText.Content, {
                                        tagName: 'h3',
                                        value: attributes.addonTitle
                                    }) : '',
                                    attributes.addonSubtitle !== '' ? el(RichText.Content, {
                                        tagName: 'p',
                                        value: attributes.addonSubtitle
                                    }) : '',
                                ),
                            ),
                            addons.map(function(addon, index) {
                                return el(
                                    Fragment, {
                                        key: index
                                    },
                                    el('div', {
                                            className: 'cwp-inner-wrap cwp-inner-wrap-equal'
                                        },
                                        el('div', {
                                                className: 'cwp-content-wrap cwp-content-wrap-box'
                                            },
                                            el(RichText.Content, {
                                                tagName: 'h3',
                                                value: addon.price
                                            }),
                                            el(RichText.Content, {
                                                tagName: 'p',
                                                value: addon.extra
                                            }),
                                        ),
                                    )
                                );
                            })
                        )
                    ) : '',
                    attributes.actionTitle !== '' || attributes.actionSubtitle !== '' || (actionsExists.indexOf('yes') > -1) ? el('div', {
                            className: 'cwp-pricelist-action cwp-main-wrapper-outer'
                        },
                        el('div', {
                                className: 'cwp-main-wrapper cwp-' + (attributes.columns + 1) + '-column'
                            },
                            el('div', {
                                    className: 'cwp-inner-wrap cwp-inner-wrap-first'
                                },
                                el('div', {
                                        className: 'cwp-content-wrap cwp-content-wrap-box' /* + (Object.keys(block_back_style()).length !== 0 ? ' cwp-content-wrap-has-background' : '')*/
                                    },
                                    attributes.actionTitle !== '' ? el(RichText.Content, {
                                        tagName: 'h3',
                                        value: attributes.actionTitle
                                    }) : '',
                                    attributes.actionSubtitle !== '' ? el(RichText.Content, {
                                        tagName: 'p',
                                        value: attributes.actionSubtitle
                                    }) : '',
                                ),
                            ),
                            actions.map(function(action, index) {
                                return el(
                                    Fragment, {
                                        key: index
                                    },
                                    el('div', {
                                            className: 'cwp-inner-wrap cwp-inner-wrap-equal'
                                        },
                                        el('div', {
                                                className: 'cwp-content-wrap cwp-content-wrap-box'
                                            },
                                            action.primaryReadmoreURL !== '' && action.primaryReadmoreURL.length > 0 && action.primaryReadmoreText !== '' && el('div', {
													className: 'cwp-button-wrap'
												},
												el(RichText.Content, {
													tagName: 'a',
													value: action.primaryReadmoreText,
													className: action.primaryStyle,
													href: action.primaryReadmoreURL,
													target: action.primaryTarget,
													rel: action.primaryTarget ? 'noopener noreferrer' : null
												})
											),
											action.secondaryReadmoreURL !== '' && action.secondaryReadmoreURL.length > 0 && action.secondaryReadmoreText !== '' && el('div', {
													className: 'cwp-button-wrap'
												},
												 el(RichText.Content, {
													tagName: 'a',
													value: action.secondaryReadmoreText,
													className: action.secondaryStyle,
													href: action.secondaryReadmoreURL,
													target: action.secondaryTarget,
													rel: action.secondaryTarget ? 'noopener noreferrer' : null
												})
											)
                                        )
                                    )
                                );
                            })
                        )
                    ) : '',
                    attributes.extra !== '' ? el('div', {
                            className: 'cwp-pricelist-extra cwp-main-wrapper-outer'
                        },
                        el('div', {
                                className: 'cwp-main-wrapper cwp-1-column'
                            },
                            el('div', {
                                    className: 'cwp-inner-wrap'
                                },
                                el('div', {
                                        className: 'cwp-content-wrap cwp-content-wrap-box'
                                    },
                                    el(RichText.Content, {
                                        tagName: 'p',
                                        value: attributes.extra
                                    }),
                                ),
                            )
                        )
                    ) : ''
                )
            );
        }
	});
})(
    window.wp
);